"""RingTolerance"""
from __future__ import annotations

from typing import TYPE_CHECKING, ClassVar

from mastapy._private._internal.dataclasses import extended_dataclass
from mastapy._private._internal import constructor, utility
from mastapy._private.bearings.tolerances import _1961
from mastapy._private._internal.cast_exception import CastException
from mastapy._private._internal.python_net import python_net_import

_RING_TOLERANCE = python_net_import("SMT.MastaAPI.Bearings.Tolerances", "RingTolerance")

if TYPE_CHECKING:
    from typing import Any, Type, TypeVar

    from mastapy._private.bearings.tolerances import _1970, _1958, _1964, _1953

    Self = TypeVar("Self", bound="RingTolerance")
    CastSelf = TypeVar("CastSelf", bound="RingTolerance._Cast_RingTolerance")


__docformat__ = "restructuredtext en"
__all__ = ("RingTolerance",)


@extended_dataclass(frozen=True, slots=True, weakref_slot=True)
class _Cast_RingTolerance:
    """Special nested class for casting RingTolerance to subclasses."""

    __parent__: "RingTolerance"

    @property
    def interference_tolerance(self: "CastSelf") -> "_1961.InterferenceTolerance":
        return self.__parent__._cast(_1961.InterferenceTolerance)

    @property
    def bearing_connection_component(
        self: "CastSelf",
    ) -> "_1953.BearingConnectionComponent":
        from mastapy._private.bearings.tolerances import _1953

        return self.__parent__._cast(_1953.BearingConnectionComponent)

    @property
    def inner_ring_tolerance(self: "CastSelf") -> "_1958.InnerRingTolerance":
        from mastapy._private.bearings.tolerances import _1958

        return self.__parent__._cast(_1958.InnerRingTolerance)

    @property
    def outer_ring_tolerance(self: "CastSelf") -> "_1964.OuterRingTolerance":
        from mastapy._private.bearings.tolerances import _1964

        return self.__parent__._cast(_1964.OuterRingTolerance)

    @property
    def ring_tolerance(self: "CastSelf") -> "RingTolerance":
        return self.__parent__

    def __getattr__(self: "CastSelf", name: str) -> "Any":
        try:
            return self.__getattribute__(name)
        except AttributeError:
            class_name = utility.camel(name)
            raise CastException(
                f'Detected an invalid cast. Cannot cast to type "{class_name}"'
            ) from None


@extended_dataclass(frozen=True, slots=True, weakref_slot=True)
class RingTolerance(_1961.InterferenceTolerance):
    """RingTolerance

    This is a mastapy class.
    """

    TYPE: ClassVar["Type"] = _RING_TOLERANCE

    wrapped: "Any"

    def __post_init__(self: "Self") -> None:
        """Override of the post initialisation magic method."""
        if not hasattr(self.wrapped, "reference_count"):
            self.wrapped.reference_count = 0

        self.wrapped.reference_count += 1

    @property
    def roundness_specification(self: "Self") -> "_1970.RoundnessSpecification":
        """mastapy._private.bearings.tolerances.RoundnessSpecification

        Note:
            This property is readonly.
        """
        temp = self.wrapped.RoundnessSpecification

        if temp is None:
            return None

        type_ = temp.GetType()
        return constructor.new(type_.Namespace, type_.Name)(temp)

    @property
    def cast_to(self: "Self") -> "_Cast_RingTolerance":
        """Cast to another type.

        Returns:
            _Cast_RingTolerance
        """
        return _Cast_RingTolerance(self)



"""Material"""
from __future__ import annotations

from typing import TYPE_CHECKING, ClassVar

from mastapy._private._internal.dataclasses import extended_dataclass
from mastapy._private._internal.type_enforcement import enforce_parameter_types
from mastapy._private._internal import constructor, conversion, utility
from mastapy._private.utility.databases import _1879
from mastapy._private._internal.cast_exception import CastException
from mastapy._private._internal.python_net import python_net_import

_MATERIAL = python_net_import("SMT.MastaAPI.Materials", "Material")

if TYPE_CHECKING:
    from typing import Any, Type, TypeVar

    from mastapy._private.materials import _269, _285, _256
    from mastapy._private.shafts import _24
    from mastapy._private.gears.materials import (
        _594,
        _597,
        _599,
        _604,
        _608,
        _616,
        _621,
        _625,
    )
    from mastapy._private.electric_machines import _1328, _1346, _1359
    from mastapy._private.detailed_rigid_connectors.splines import _1462
    from mastapy._private.cycloidal import _1502, _1509
    from mastapy._private.bolts import _1512, _1516

    Self = TypeVar("Self", bound="Material")
    CastSelf = TypeVar("CastSelf", bound="Material._Cast_Material")


__docformat__ = "restructuredtext en"
__all__ = ("Material",)


@extended_dataclass(frozen=True, slots=True, weakref_slot=True)
class _Cast_Material:
    """Special nested class for casting Material to subclasses."""

    __parent__: "Material"

    @property
    def named_database_item(self: "CastSelf") -> "_1879.NamedDatabaseItem":
        return self.__parent__._cast(_1879.NamedDatabaseItem)

    @property
    def shaft_material(self: "CastSelf") -> "_24.ShaftMaterial":
        from mastapy._private.shafts import _24

        return self.__parent__._cast(_24.ShaftMaterial)

    @property
    def bearing_material(self: "CastSelf") -> "_256.BearingMaterial":
        from mastapy._private.materials import _256

        return self.__parent__._cast(_256.BearingMaterial)

    @property
    def agma_cylindrical_gear_material(
        self: "CastSelf",
    ) -> "_594.AGMACylindricalGearMaterial":
        from mastapy._private.gears.materials import _594

        return self.__parent__._cast(_594.AGMACylindricalGearMaterial)

    @property
    def bevel_gear_iso_material(self: "CastSelf") -> "_597.BevelGearISOMaterial":
        from mastapy._private.gears.materials import _597

        return self.__parent__._cast(_597.BevelGearISOMaterial)

    @property
    def bevel_gear_material(self: "CastSelf") -> "_599.BevelGearMaterial":
        from mastapy._private.gears.materials import _599

        return self.__parent__._cast(_599.BevelGearMaterial)

    @property
    def cylindrical_gear_material(self: "CastSelf") -> "_604.CylindricalGearMaterial":
        from mastapy._private.gears.materials import _604

        return self.__parent__._cast(_604.CylindricalGearMaterial)

    @property
    def gear_material(self: "CastSelf") -> "_608.GearMaterial":
        from mastapy._private.gears.materials import _608

        return self.__parent__._cast(_608.GearMaterial)

    @property
    def iso_cylindrical_gear_material(
        self: "CastSelf",
    ) -> "_616.ISOCylindricalGearMaterial":
        from mastapy._private.gears.materials import _616

        return self.__parent__._cast(_616.ISOCylindricalGearMaterial)

    @property
    def klingelnberg_cyclo_palloid_conical_gear_material(
        self: "CastSelf",
    ) -> "_621.KlingelnbergCycloPalloidConicalGearMaterial":
        from mastapy._private.gears.materials import _621

        return self.__parent__._cast(_621.KlingelnbergCycloPalloidConicalGearMaterial)

    @property
    def plastic_cylindrical_gear_material(
        self: "CastSelf",
    ) -> "_625.PlasticCylindricalGearMaterial":
        from mastapy._private.gears.materials import _625

        return self.__parent__._cast(_625.PlasticCylindricalGearMaterial)

    @property
    def magnet_material(self: "CastSelf") -> "_1328.MagnetMaterial":
        from mastapy._private.electric_machines import _1328

        return self.__parent__._cast(_1328.MagnetMaterial)

    @property
    def stator_rotor_material(self: "CastSelf") -> "_1346.StatorRotorMaterial":
        from mastapy._private.electric_machines import _1346

        return self.__parent__._cast(_1346.StatorRotorMaterial)

    @property
    def winding_material(self: "CastSelf") -> "_1359.WindingMaterial":
        from mastapy._private.electric_machines import _1359

        return self.__parent__._cast(_1359.WindingMaterial)

    @property
    def spline_material(self: "CastSelf") -> "_1462.SplineMaterial":
        from mastapy._private.detailed_rigid_connectors.splines import _1462

        return self.__parent__._cast(_1462.SplineMaterial)

    @property
    def cycloidal_disc_material(self: "CastSelf") -> "_1502.CycloidalDiscMaterial":
        from mastapy._private.cycloidal import _1502

        return self.__parent__._cast(_1502.CycloidalDiscMaterial)

    @property
    def ring_pins_material(self: "CastSelf") -> "_1509.RingPinsMaterial":
        from mastapy._private.cycloidal import _1509

        return self.__parent__._cast(_1509.RingPinsMaterial)

    @property
    def bolted_joint_material(self: "CastSelf") -> "_1512.BoltedJointMaterial":
        from mastapy._private.bolts import _1512

        return self.__parent__._cast(_1512.BoltedJointMaterial)

    @property
    def bolt_material(self: "CastSelf") -> "_1516.BoltMaterial":
        from mastapy._private.bolts import _1516

        return self.__parent__._cast(_1516.BoltMaterial)

    @property
    def material(self: "CastSelf") -> "Material":
        return self.__parent__

    def __getattr__(self: "CastSelf", name: str) -> "Any":
        try:
            return self.__getattribute__(name)
        except AttributeError:
            class_name = utility.camel(name)
            raise CastException(
                f'Detected an invalid cast. Cannot cast to type "{class_name}"'
            ) from None


@extended_dataclass(frozen=True, slots=True, weakref_slot=True)
class Material(_1879.NamedDatabaseItem):
    """Material

    This is a mastapy class.
    """

    TYPE: ClassVar["Type"] = _MATERIAL

    wrapped: "Any"

    def __post_init__(self: "Self") -> None:
        """Override of the post initialisation magic method."""
        if not hasattr(self.wrapped, "reference_count"):
            self.wrapped.reference_count = 0

        self.wrapped.reference_count += 1

    @property
    def coefficient_of_thermal_expansion(self: "Self") -> "float":
        """float"""
        temp = self.wrapped.CoefficientOfThermalExpansion

        if temp is None:
            return 0.0

        return temp

    @coefficient_of_thermal_expansion.setter
    @enforce_parameter_types
    def coefficient_of_thermal_expansion(self: "Self", value: "float") -> None:
        self.wrapped.CoefficientOfThermalExpansion = (
            float(value) if value is not None else 0.0
        )

    @property
    def cost_per_unit_mass(self: "Self") -> "float":
        """float"""
        temp = self.wrapped.CostPerUnitMass

        if temp is None:
            return 0.0

        return temp

    @cost_per_unit_mass.setter
    @enforce_parameter_types
    def cost_per_unit_mass(self: "Self", value: "float") -> None:
        self.wrapped.CostPerUnitMass = float(value) if value is not None else 0.0

    @property
    def density(self: "Self") -> "float":
        """float"""
        temp = self.wrapped.Density

        if temp is None:
            return 0.0

        return temp

    @density.setter
    @enforce_parameter_types
    def density(self: "Self", value: "float") -> None:
        self.wrapped.Density = float(value) if value is not None else 0.0

    @property
    def hardness_type(self: "Self") -> "_269.HardnessType":
        """mastapy._private.materials.HardnessType"""
        temp = self.wrapped.HardnessType

        if temp is None:
            return None

        value = conversion.pn_to_mp_enum(temp, "SMT.MastaAPI.Materials.HardnessType")

        if value is None:
            return None

        return constructor.new_from_mastapy(
            "mastapy._private.materials._269", "HardnessType"
        )(value)

    @hardness_type.setter
    @enforce_parameter_types
    def hardness_type(self: "Self", value: "_269.HardnessType") -> None:
        value = conversion.mp_to_pn_enum(value, "SMT.MastaAPI.Materials.HardnessType")
        self.wrapped.HardnessType = value

    @property
    def heat_conductivity(self: "Self") -> "float":
        """float"""
        temp = self.wrapped.HeatConductivity

        if temp is None:
            return 0.0

        return temp

    @heat_conductivity.setter
    @enforce_parameter_types
    def heat_conductivity(self: "Self", value: "float") -> None:
        self.wrapped.HeatConductivity = float(value) if value is not None else 0.0

    @property
    def material_name(self: "Self") -> "str":
        """str

        Note:
            This property is readonly.
        """
        temp = self.wrapped.MaterialName

        if temp is None:
            return ""

        return temp

    @property
    def maximum_allowable_temperature(self: "Self") -> "float":
        """float"""
        temp = self.wrapped.MaximumAllowableTemperature

        if temp is None:
            return 0.0

        return temp

    @maximum_allowable_temperature.setter
    @enforce_parameter_types
    def maximum_allowable_temperature(self: "Self", value: "float") -> None:
        self.wrapped.MaximumAllowableTemperature = (
            float(value) if value is not None else 0.0
        )

    @property
    def modulus_of_elasticity(self: "Self") -> "float":
        """float"""
        temp = self.wrapped.ModulusOfElasticity

        if temp is None:
            return 0.0

        return temp

    @modulus_of_elasticity.setter
    @enforce_parameter_types
    def modulus_of_elasticity(self: "Self", value: "float") -> None:
        self.wrapped.ModulusOfElasticity = float(value) if value is not None else 0.0

    @property
    def plane_strain_modulus(self: "Self") -> "float":
        """float

        Note:
            This property is readonly.
        """
        temp = self.wrapped.PlaneStrainModulus

        if temp is None:
            return 0.0

        return temp

    @property
    def poissons_ratio(self: "Self") -> "float":
        """float"""
        temp = self.wrapped.PoissonsRatio

        if temp is None:
            return 0.0

        return temp

    @poissons_ratio.setter
    @enforce_parameter_types
    def poissons_ratio(self: "Self", value: "float") -> None:
        self.wrapped.PoissonsRatio = float(value) if value is not None else 0.0

    @property
    def shear_fatigue_strength(self: "Self") -> "float":
        """float

        Note:
            This property is readonly.
        """
        temp = self.wrapped.ShearFatigueStrength

        if temp is None:
            return 0.0

        return temp

    @property
    def shear_modulus(self: "Self") -> "float":
        """float

        Note:
            This property is readonly.
        """
        temp = self.wrapped.ShearModulus

        if temp is None:
            return 0.0

        return temp

    @property
    def shear_yield_stress(self: "Self") -> "float":
        """float

        Note:
            This property is readonly.
        """
        temp = self.wrapped.ShearYieldStress

        if temp is None:
            return 0.0

        return temp

    @property
    def specific_heat(self: "Self") -> "float":
        """float"""
        temp = self.wrapped.SpecificHeat

        if temp is None:
            return 0.0

        return temp

    @specific_heat.setter
    @enforce_parameter_types
    def specific_heat(self: "Self", value: "float") -> None:
        self.wrapped.SpecificHeat = float(value) if value is not None else 0.0

    @property
    def standard(self: "Self") -> "_285.MaterialStandards":
        """mastapy._private.materials.MaterialStandards

        Note:
            This property is readonly.
        """
        temp = self.wrapped.Standard

        if temp is None:
            return None

        value = conversion.pn_to_mp_enum(
            temp, "SMT.MastaAPI.Materials.MaterialStandards"
        )

        if value is None:
            return None

        return constructor.new_from_mastapy(
            "mastapy._private.materials._285", "MaterialStandards"
        )(value)

    @property
    def surface_hardness(self: "Self") -> "float":
        """float"""
        temp = self.wrapped.SurfaceHardness

        if temp is None:
            return 0.0

        return temp

    @surface_hardness.setter
    @enforce_parameter_types
    def surface_hardness(self: "Self", value: "float") -> None:
        self.wrapped.SurfaceHardness = float(value) if value is not None else 0.0

    @property
    def surface_hardness_range_max_in_hb(self: "Self") -> "float":
        """float

        Note:
            This property is readonly.
        """
        temp = self.wrapped.SurfaceHardnessRangeMaxInHB

        if temp is None:
            return 0.0

        return temp

    @property
    def surface_hardness_range_max_in_hrc(self: "Self") -> "float":
        """float

        Note:
            This property is readonly.
        """
        temp = self.wrapped.SurfaceHardnessRangeMaxInHRC

        if temp is None:
            return 0.0

        return temp

    @property
    def surface_hardness_range_max_in_hv(self: "Self") -> "float":
        """float

        Note:
            This property is readonly.
        """
        temp = self.wrapped.SurfaceHardnessRangeMaxInHV

        if temp is None:
            return 0.0

        return temp

    @property
    def surface_hardness_range_min_in_hb(self: "Self") -> "float":
        """float

        Note:
            This property is readonly.
        """
        temp = self.wrapped.SurfaceHardnessRangeMinInHB

        if temp is None:
            return 0.0

        return temp

    @property
    def surface_hardness_range_min_in_hrc(self: "Self") -> "float":
        """float

        Note:
            This property is readonly.
        """
        temp = self.wrapped.SurfaceHardnessRangeMinInHRC

        if temp is None:
            return 0.0

        return temp

    @property
    def surface_hardness_range_min_in_hv(self: "Self") -> "float":
        """float

        Note:
            This property is readonly.
        """
        temp = self.wrapped.SurfaceHardnessRangeMinInHV

        if temp is None:
            return 0.0

        return temp

    @property
    def tensile_yield_strength(self: "Self") -> "float":
        """float"""
        temp = self.wrapped.TensileYieldStrength

        if temp is None:
            return 0.0

        return temp

    @tensile_yield_strength.setter
    @enforce_parameter_types
    def tensile_yield_strength(self: "Self", value: "float") -> None:
        self.wrapped.TensileYieldStrength = float(value) if value is not None else 0.0

    @property
    def ultimate_tensile_strength(self: "Self") -> "float":
        """float"""
        temp = self.wrapped.UltimateTensileStrength

        if temp is None:
            return 0.0

        return temp

    @ultimate_tensile_strength.setter
    @enforce_parameter_types
    def ultimate_tensile_strength(self: "Self", value: "float") -> None:
        self.wrapped.UltimateTensileStrength = (
            float(value) if value is not None else 0.0
        )

    @property
    def cast_to(self: "Self") -> "_Cast_Material":
        """Cast to another type.

        Returns:
            _Cast_Material
        """
        return _Cast_Material(self)



"""ConicalGearLoadCase"""
from __future__ import annotations

from typing import TYPE_CHECKING, ClassVar

from mastapy._private._internal.dataclasses import extended_dataclass
from mastapy._private._internal import constructor, conversion, utility
from mastapy._private.system_model.analyses_and_results.static_loads import _7037
from mastapy._private._internal.cast_exception import CastException
from mastapy._private._internal.python_net import python_net_import

_CONICAL_GEAR_LOAD_CASE = python_net_import(
    "SMT.MastaAPI.SystemModel.AnalysesAndResults.StaticLoads", "ConicalGearLoadCase"
)

if TYPE_CHECKING:
    from typing import Any, Type, List, TypeVar

    from mastapy._private.system_model.part_model.gears import _2579
    from mastapy._private.system_model.analyses_and_results.static_loads import (
        _6992,
        _6960,
        _6969,
        _6972,
        _6973,
        _6974,
        _7052,
        _7059,
        _7062,
        _7065,
        _7102,
        _7108,
        _7111,
        _7114,
        _7115,
        _7134,
        _7073,
        _6984,
        _7077,
    )
    from mastapy._private.system_model.analyses_and_results import _2740, _2736, _2734

    Self = TypeVar("Self", bound="ConicalGearLoadCase")
    CastSelf = TypeVar(
        "CastSelf", bound="ConicalGearLoadCase._Cast_ConicalGearLoadCase"
    )


__docformat__ = "restructuredtext en"
__all__ = ("ConicalGearLoadCase",)


@extended_dataclass(frozen=True, slots=True, weakref_slot=True)
class _Cast_ConicalGearLoadCase:
    """Special nested class for casting ConicalGearLoadCase to subclasses."""

    __parent__: "ConicalGearLoadCase"

    @property
    def gear_load_case(self: "CastSelf") -> "_7037.GearLoadCase":
        return self.__parent__._cast(_7037.GearLoadCase)

    @property
    def mountable_component_load_case(
        self: "CastSelf",
    ) -> "_7073.MountableComponentLoadCase":
        from mastapy._private.system_model.analyses_and_results.static_loads import (
            _7073,
        )

        return self.__parent__._cast(_7073.MountableComponentLoadCase)

    @property
    def component_load_case(self: "CastSelf") -> "_6984.ComponentLoadCase":
        from mastapy._private.system_model.analyses_and_results.static_loads import (
            _6984,
        )

        return self.__parent__._cast(_6984.ComponentLoadCase)

    @property
    def part_load_case(self: "CastSelf") -> "_7077.PartLoadCase":
        from mastapy._private.system_model.analyses_and_results.static_loads import (
            _7077,
        )

        return self.__parent__._cast(_7077.PartLoadCase)

    @property
    def part_analysis(self: "CastSelf") -> "_2740.PartAnalysis":
        from mastapy._private.system_model.analyses_and_results import _2740

        return self.__parent__._cast(_2740.PartAnalysis)

    @property
    def design_entity_single_context_analysis(
        self: "CastSelf",
    ) -> "_2736.DesignEntitySingleContextAnalysis":
        from mastapy._private.system_model.analyses_and_results import _2736

        return self.__parent__._cast(_2736.DesignEntitySingleContextAnalysis)

    @property
    def design_entity_analysis(self: "CastSelf") -> "_2734.DesignEntityAnalysis":
        from mastapy._private.system_model.analyses_and_results import _2734

        return self.__parent__._cast(_2734.DesignEntityAnalysis)

    @property
    def agma_gleason_conical_gear_load_case(
        self: "CastSelf",
    ) -> "_6960.AGMAGleasonConicalGearLoadCase":
        from mastapy._private.system_model.analyses_and_results.static_loads import (
            _6960,
        )

        return self.__parent__._cast(_6960.AGMAGleasonConicalGearLoadCase)

    @property
    def bevel_differential_gear_load_case(
        self: "CastSelf",
    ) -> "_6969.BevelDifferentialGearLoadCase":
        from mastapy._private.system_model.analyses_and_results.static_loads import (
            _6969,
        )

        return self.__parent__._cast(_6969.BevelDifferentialGearLoadCase)

    @property
    def bevel_differential_planet_gear_load_case(
        self: "CastSelf",
    ) -> "_6972.BevelDifferentialPlanetGearLoadCase":
        from mastapy._private.system_model.analyses_and_results.static_loads import (
            _6972,
        )

        return self.__parent__._cast(_6972.BevelDifferentialPlanetGearLoadCase)

    @property
    def bevel_differential_sun_gear_load_case(
        self: "CastSelf",
    ) -> "_6973.BevelDifferentialSunGearLoadCase":
        from mastapy._private.system_model.analyses_and_results.static_loads import (
            _6973,
        )

        return self.__parent__._cast(_6973.BevelDifferentialSunGearLoadCase)

    @property
    def bevel_gear_load_case(self: "CastSelf") -> "_6974.BevelGearLoadCase":
        from mastapy._private.system_model.analyses_and_results.static_loads import (
            _6974,
        )

        return self.__parent__._cast(_6974.BevelGearLoadCase)

    @property
    def hypoid_gear_load_case(self: "CastSelf") -> "_7052.HypoidGearLoadCase":
        from mastapy._private.system_model.analyses_and_results.static_loads import (
            _7052,
        )

        return self.__parent__._cast(_7052.HypoidGearLoadCase)

    @property
    def klingelnberg_cyclo_palloid_conical_gear_load_case(
        self: "CastSelf",
    ) -> "_7059.KlingelnbergCycloPalloidConicalGearLoadCase":
        from mastapy._private.system_model.analyses_and_results.static_loads import (
            _7059,
        )

        return self.__parent__._cast(_7059.KlingelnbergCycloPalloidConicalGearLoadCase)

    @property
    def klingelnberg_cyclo_palloid_hypoid_gear_load_case(
        self: "CastSelf",
    ) -> "_7062.KlingelnbergCycloPalloidHypoidGearLoadCase":
        from mastapy._private.system_model.analyses_and_results.static_loads import (
            _7062,
        )

        return self.__parent__._cast(_7062.KlingelnbergCycloPalloidHypoidGearLoadCase)

    @property
    def klingelnberg_cyclo_palloid_spiral_bevel_gear_load_case(
        self: "CastSelf",
    ) -> "_7065.KlingelnbergCycloPalloidSpiralBevelGearLoadCase":
        from mastapy._private.system_model.analyses_and_results.static_loads import (
            _7065,
        )

        return self.__parent__._cast(
            _7065.KlingelnbergCycloPalloidSpiralBevelGearLoadCase
        )

    @property
    def spiral_bevel_gear_load_case(
        self: "CastSelf",
    ) -> "_7102.SpiralBevelGearLoadCase":
        from mastapy._private.system_model.analyses_and_results.static_loads import (
            _7102,
        )

        return self.__parent__._cast(_7102.SpiralBevelGearLoadCase)

    @property
    def straight_bevel_diff_gear_load_case(
        self: "CastSelf",
    ) -> "_7108.StraightBevelDiffGearLoadCase":
        from mastapy._private.system_model.analyses_and_results.static_loads import (
            _7108,
        )

        return self.__parent__._cast(_7108.StraightBevelDiffGearLoadCase)

    @property
    def straight_bevel_gear_load_case(
        self: "CastSelf",
    ) -> "_7111.StraightBevelGearLoadCase":
        from mastapy._private.system_model.analyses_and_results.static_loads import (
            _7111,
        )

        return self.__parent__._cast(_7111.StraightBevelGearLoadCase)

    @property
    def straight_bevel_planet_gear_load_case(
        self: "CastSelf",
    ) -> "_7114.StraightBevelPlanetGearLoadCase":
        from mastapy._private.system_model.analyses_and_results.static_loads import (
            _7114,
        )

        return self.__parent__._cast(_7114.StraightBevelPlanetGearLoadCase)

    @property
    def straight_bevel_sun_gear_load_case(
        self: "CastSelf",
    ) -> "_7115.StraightBevelSunGearLoadCase":
        from mastapy._private.system_model.analyses_and_results.static_loads import (
            _7115,
        )

        return self.__parent__._cast(_7115.StraightBevelSunGearLoadCase)

    @property
    def zerol_bevel_gear_load_case(self: "CastSelf") -> "_7134.ZerolBevelGearLoadCase":
        from mastapy._private.system_model.analyses_and_results.static_loads import (
            _7134,
        )

        return self.__parent__._cast(_7134.ZerolBevelGearLoadCase)

    @property
    def conical_gear_load_case(self: "CastSelf") -> "ConicalGearLoadCase":
        return self.__parent__

    def __getattr__(self: "CastSelf", name: str) -> "Any":
        try:
            return self.__getattribute__(name)
        except AttributeError:
            class_name = utility.camel(name)
            raise CastException(
                f'Detected an invalid cast. Cannot cast to type "{class_name}"'
            ) from None


@extended_dataclass(frozen=True, slots=True, weakref_slot=True)
class ConicalGearLoadCase(_7037.GearLoadCase):
    """ConicalGearLoadCase

    This is a mastapy class.
    """

    TYPE: ClassVar["Type"] = _CONICAL_GEAR_LOAD_CASE

    wrapped: "Any"

    def __post_init__(self: "Self") -> None:
        """Override of the post initialisation magic method."""
        if not hasattr(self.wrapped, "reference_count"):
            self.wrapped.reference_count = 0

        self.wrapped.reference_count += 1

    @property
    def component_design(self: "Self") -> "_2579.ConicalGear":
        """mastapy._private.system_model.part_model.gears.ConicalGear

        Note:
            This property is readonly.
        """
        temp = self.wrapped.ComponentDesign

        if temp is None:
            return None

        type_ = temp.GetType()
        return constructor.new(type_.Namespace, type_.Name)(temp)

    @property
    def gear_manufacture_errors(self: "Self") -> "_6992.ConicalGearManufactureError":
        """mastapy._private.system_model.analyses_and_results.static_loads.ConicalGearManufactureError

        Note:
            This property is readonly.
        """
        temp = self.wrapped.GearManufactureErrors

        if temp is None:
            return None

        type_ = temp.GetType()
        return constructor.new(type_.Namespace, type_.Name)(temp)

    @property
    def planetaries(self: "Self") -> "List[ConicalGearLoadCase]":
        """List[mastapy._private.system_model.analyses_and_results.static_loads.ConicalGearLoadCase]

        Note:
            This property is readonly.
        """
        temp = self.wrapped.Planetaries

        if temp is None:
            return None

        value = conversion.pn_to_mp_objects_in_list(temp)

        if value is None:
            return None

        return value

    @property
    def cast_to(self: "Self") -> "_Cast_ConicalGearLoadCase":
        """Cast to another type.

        Returns:
            _Cast_ConicalGearLoadCase
        """
        return _Cast_ConicalGearLoadCase(self)



"""ConicalGearSetCompoundStabilityAnalysis"""
from __future__ import annotations

from typing import TYPE_CHECKING, ClassVar

from mastapy._private._internal.dataclasses import extended_dataclass
from mastapy._private._internal import conversion, utility
from mastapy._private.system_model.analyses_and_results.stability_analyses.compound import (
    _4058,
)
from mastapy._private._internal.cast_exception import CastException
from mastapy._private._internal.python_net import python_net_import

_CONICAL_GEAR_SET_COMPOUND_STABILITY_ANALYSIS = python_net_import(
    "SMT.MastaAPI.SystemModel.AnalysesAndResults.StabilityAnalyses.Compound",
    "ConicalGearSetCompoundStabilityAnalysis",
)

if TYPE_CHECKING:
    from typing import Any, Type, List, TypeVar

    from mastapy._private.system_model.analyses_and_results.stability_analyses import (
        _3895,
    )
    from mastapy._private.system_model.analyses_and_results.stability_analyses.compound import (
        _4004,
        _4011,
        _4016,
        _4062,
        _4066,
        _4069,
        _4072,
        _4101,
        _4107,
        _4110,
        _4128,
        _4098,
        _3998,
        _4079,
    )
    from mastapy._private.system_model.analyses_and_results.analysis_cases import (
        _7711,
        _7708,
    )
    from mastapy._private.system_model.analyses_and_results import _2734

    Self = TypeVar("Self", bound="ConicalGearSetCompoundStabilityAnalysis")
    CastSelf = TypeVar(
        "CastSelf",
        bound="ConicalGearSetCompoundStabilityAnalysis._Cast_ConicalGearSetCompoundStabilityAnalysis",
    )


__docformat__ = "restructuredtext en"
__all__ = ("ConicalGearSetCompoundStabilityAnalysis",)


@extended_dataclass(frozen=True, slots=True, weakref_slot=True)
class _Cast_ConicalGearSetCompoundStabilityAnalysis:
    """Special nested class for casting ConicalGearSetCompoundStabilityAnalysis to subclasses."""

    __parent__: "ConicalGearSetCompoundStabilityAnalysis"

    @property
    def gear_set_compound_stability_analysis(
        self: "CastSelf",
    ) -> "_4058.GearSetCompoundStabilityAnalysis":
        return self.__parent__._cast(_4058.GearSetCompoundStabilityAnalysis)

    @property
    def specialised_assembly_compound_stability_analysis(
        self: "CastSelf",
    ) -> "_4098.SpecialisedAssemblyCompoundStabilityAnalysis":
        from mastapy._private.system_model.analyses_and_results.stability_analyses.compound import (
            _4098,
        )

        return self.__parent__._cast(_4098.SpecialisedAssemblyCompoundStabilityAnalysis)

    @property
    def abstract_assembly_compound_stability_analysis(
        self: "CastSelf",
    ) -> "_3998.AbstractAssemblyCompoundStabilityAnalysis":
        from mastapy._private.system_model.analyses_and_results.stability_analyses.compound import (
            _3998,
        )

        return self.__parent__._cast(_3998.AbstractAssemblyCompoundStabilityAnalysis)

    @property
    def part_compound_stability_analysis(
        self: "CastSelf",
    ) -> "_4079.PartCompoundStabilityAnalysis":
        from mastapy._private.system_model.analyses_and_results.stability_analyses.compound import (
            _4079,
        )

        return self.__parent__._cast(_4079.PartCompoundStabilityAnalysis)

    @property
    def part_compound_analysis(self: "CastSelf") -> "_7711.PartCompoundAnalysis":
        from mastapy._private.system_model.analyses_and_results.analysis_cases import (
            _7711,
        )

        return self.__parent__._cast(_7711.PartCompoundAnalysis)

    @property
    def design_entity_compound_analysis(
        self: "CastSelf",
    ) -> "_7708.DesignEntityCompoundAnalysis":
        from mastapy._private.system_model.analyses_and_results.analysis_cases import (
            _7708,
        )

        return self.__parent__._cast(_7708.DesignEntityCompoundAnalysis)

    @property
    def design_entity_analysis(self: "CastSelf") -> "_2734.DesignEntityAnalysis":
        from mastapy._private.system_model.analyses_and_results import _2734

        return self.__parent__._cast(_2734.DesignEntityAnalysis)

    @property
    def agma_gleason_conical_gear_set_compound_stability_analysis(
        self: "CastSelf",
    ) -> "_4004.AGMAGleasonConicalGearSetCompoundStabilityAnalysis":
        from mastapy._private.system_model.analyses_and_results.stability_analyses.compound import (
            _4004,
        )

        return self.__parent__._cast(
            _4004.AGMAGleasonConicalGearSetCompoundStabilityAnalysis
        )

    @property
    def bevel_differential_gear_set_compound_stability_analysis(
        self: "CastSelf",
    ) -> "_4011.BevelDifferentialGearSetCompoundStabilityAnalysis":
        from mastapy._private.system_model.analyses_and_results.stability_analyses.compound import (
            _4011,
        )

        return self.__parent__._cast(
            _4011.BevelDifferentialGearSetCompoundStabilityAnalysis
        )

    @property
    def bevel_gear_set_compound_stability_analysis(
        self: "CastSelf",
    ) -> "_4016.BevelGearSetCompoundStabilityAnalysis":
        from mastapy._private.system_model.analyses_and_results.stability_analyses.compound import (
            _4016,
        )

        return self.__parent__._cast(_4016.BevelGearSetCompoundStabilityAnalysis)

    @property
    def hypoid_gear_set_compound_stability_analysis(
        self: "CastSelf",
    ) -> "_4062.HypoidGearSetCompoundStabilityAnalysis":
        from mastapy._private.system_model.analyses_and_results.stability_analyses.compound import (
            _4062,
        )

        return self.__parent__._cast(_4062.HypoidGearSetCompoundStabilityAnalysis)

    @property
    def klingelnberg_cyclo_palloid_conical_gear_set_compound_stability_analysis(
        self: "CastSelf",
    ) -> "_4066.KlingelnbergCycloPalloidConicalGearSetCompoundStabilityAnalysis":
        from mastapy._private.system_model.analyses_and_results.stability_analyses.compound import (
            _4066,
        )

        return self.__parent__._cast(
            _4066.KlingelnbergCycloPalloidConicalGearSetCompoundStabilityAnalysis
        )

    @property
    def klingelnberg_cyclo_palloid_hypoid_gear_set_compound_stability_analysis(
        self: "CastSelf",
    ) -> "_4069.KlingelnbergCycloPalloidHypoidGearSetCompoundStabilityAnalysis":
        from mastapy._private.system_model.analyses_and_results.stability_analyses.compound import (
            _4069,
        )

        return self.__parent__._cast(
            _4069.KlingelnbergCycloPalloidHypoidGearSetCompoundStabilityAnalysis
        )

    @property
    def klingelnberg_cyclo_palloid_spiral_bevel_gear_set_compound_stability_analysis(
        self: "CastSelf",
    ) -> "_4072.KlingelnbergCycloPalloidSpiralBevelGearSetCompoundStabilityAnalysis":
        from mastapy._private.system_model.analyses_and_results.stability_analyses.compound import (
            _4072,
        )

        return self.__parent__._cast(
            _4072.KlingelnbergCycloPalloidSpiralBevelGearSetCompoundStabilityAnalysis
        )

    @property
    def spiral_bevel_gear_set_compound_stability_analysis(
        self: "CastSelf",
    ) -> "_4101.SpiralBevelGearSetCompoundStabilityAnalysis":
        from mastapy._private.system_model.analyses_and_results.stability_analyses.compound import (
            _4101,
        )

        return self.__parent__._cast(_4101.SpiralBevelGearSetCompoundStabilityAnalysis)

    @property
    def straight_bevel_diff_gear_set_compound_stability_analysis(
        self: "CastSelf",
    ) -> "_4107.StraightBevelDiffGearSetCompoundStabilityAnalysis":
        from mastapy._private.system_model.analyses_and_results.stability_analyses.compound import (
            _4107,
        )

        return self.__parent__._cast(
            _4107.StraightBevelDiffGearSetCompoundStabilityAnalysis
        )

    @property
    def straight_bevel_gear_set_compound_stability_analysis(
        self: "CastSelf",
    ) -> "_4110.StraightBevelGearSetCompoundStabilityAnalysis":
        from mastapy._private.system_model.analyses_and_results.stability_analyses.compound import (
            _4110,
        )

        return self.__parent__._cast(
            _4110.StraightBevelGearSetCompoundStabilityAnalysis
        )

    @property
    def zerol_bevel_gear_set_compound_stability_analysis(
        self: "CastSelf",
    ) -> "_4128.ZerolBevelGearSetCompoundStabilityAnalysis":
        from mastapy._private.system_model.analyses_and_results.stability_analyses.compound import (
            _4128,
        )

        return self.__parent__._cast(_4128.ZerolBevelGearSetCompoundStabilityAnalysis)

    @property
    def conical_gear_set_compound_stability_analysis(
        self: "CastSelf",
    ) -> "ConicalGearSetCompoundStabilityAnalysis":
        return self.__parent__

    def __getattr__(self: "CastSelf", name: str) -> "Any":
        try:
            return self.__getattribute__(name)
        except AttributeError:
            class_name = utility.camel(name)
            raise CastException(
                f'Detected an invalid cast. Cannot cast to type "{class_name}"'
            ) from None


@extended_dataclass(frozen=True, slots=True, weakref_slot=True)
class ConicalGearSetCompoundStabilityAnalysis(_4058.GearSetCompoundStabilityAnalysis):
    """ConicalGearSetCompoundStabilityAnalysis

    This is a mastapy class.
    """

    TYPE: ClassVar["Type"] = _CONICAL_GEAR_SET_COMPOUND_STABILITY_ANALYSIS

    wrapped: "Any"

    def __post_init__(self: "Self") -> None:
        """Override of the post initialisation magic method."""
        if not hasattr(self.wrapped, "reference_count"):
            self.wrapped.reference_count = 0

        self.wrapped.reference_count += 1

    @property
    def assembly_analysis_cases(
        self: "Self",
    ) -> "List[_3895.ConicalGearSetStabilityAnalysis]":
        """List[mastapy._private.system_model.analyses_and_results.stability_analyses.ConicalGearSetStabilityAnalysis]

        Note:
            This property is readonly.
        """
        temp = self.wrapped.AssemblyAnalysisCases

        if temp is None:
            return None

        value = conversion.pn_to_mp_objects_in_list(temp)

        if value is None:
            return None

        return value

    @property
    def assembly_analysis_cases_ready(
        self: "Self",
    ) -> "List[_3895.ConicalGearSetStabilityAnalysis]":
        """List[mastapy._private.system_model.analyses_and_results.stability_analyses.ConicalGearSetStabilityAnalysis]

        Note:
            This property is readonly.
        """
        temp = self.wrapped.AssemblyAnalysisCasesReady

        if temp is None:
            return None

        value = conversion.pn_to_mp_objects_in_list(temp)

        if value is None:
            return None

        return value

    @property
    def cast_to(self: "Self") -> "_Cast_ConicalGearSetCompoundStabilityAnalysis":
        """Cast to another type.

        Returns:
            _Cast_ConicalGearSetCompoundStabilityAnalysis
        """
        return _Cast_ConicalGearSetCompoundStabilityAnalysis(self)



"""Subpackage."""

from typing import TYPE_CHECKING as __tc


if __tc:
    from mastapy._private.system_model.analyses_and_results.stability_analyses.compound._3998 import (
        AbstractAssemblyCompoundStabilityAnalysis,
    )
    from mastapy._private.system_model.analyses_and_results.stability_analyses.compound._3999 import (
        AbstractShaftCompoundStabilityAnalysis,
    )
    from mastapy._private.system_model.analyses_and_results.stability_analyses.compound._4000 import (
        AbstractShaftOrHousingCompoundStabilityAnalysis,
    )
    from mastapy._private.system_model.analyses_and_results.stability_analyses.compound._4001 import (
        AbstractShaftToMountableComponentConnectionCompoundStabilityAnalysis,
    )
    from mastapy._private.system_model.analyses_and_results.stability_analyses.compound._4002 import (
        AGMAGleasonConicalGearCompoundStabilityAnalysis,
    )
    from mastapy._private.system_model.analyses_and_results.stability_analyses.compound._4003 import (
        AGMAGleasonConicalGearMeshCompoundStabilityAnalysis,
    )
    from mastapy._private.system_model.analyses_and_results.stability_analyses.compound._4004 import (
        AGMAGleasonConicalGearSetCompoundStabilityAnalysis,
    )
    from mastapy._private.system_model.analyses_and_results.stability_analyses.compound._4005 import (
        AssemblyCompoundStabilityAnalysis,
    )
    from mastapy._private.system_model.analyses_and_results.stability_analyses.compound._4006 import (
        BearingCompoundStabilityAnalysis,
    )
    from mastapy._private.system_model.analyses_and_results.stability_analyses.compound._4007 import (
        BeltConnectionCompoundStabilityAnalysis,
    )
    from mastapy._private.system_model.analyses_and_results.stability_analyses.compound._4008 import (
        BeltDriveCompoundStabilityAnalysis,
    )
    from mastapy._private.system_model.analyses_and_results.stability_analyses.compound._4009 import (
        BevelDifferentialGearCompoundStabilityAnalysis,
    )
    from mastapy._private.system_model.analyses_and_results.stability_analyses.compound._4010 import (
        BevelDifferentialGearMeshCompoundStabilityAnalysis,
    )
    from mastapy._private.system_model.analyses_and_results.stability_analyses.compound._4011 import (
        BevelDifferentialGearSetCompoundStabilityAnalysis,
    )
    from mastapy._private.system_model.analyses_and_results.stability_analyses.compound._4012 import (
        BevelDifferentialPlanetGearCompoundStabilityAnalysis,
    )
    from mastapy._private.system_model.analyses_and_results.stability_analyses.compound._4013 import (
        BevelDifferentialSunGearCompoundStabilityAnalysis,
    )
    from mastapy._private.system_model.analyses_and_results.stability_analyses.compound._4014 import (
        BevelGearCompoundStabilityAnalysis,
    )
    from mastapy._private.system_model.analyses_and_results.stability_analyses.compound._4015 import (
        BevelGearMeshCompoundStabilityAnalysis,
    )
    from mastapy._private.system_model.analyses_and_results.stability_analyses.compound._4016 import (
        BevelGearSetCompoundStabilityAnalysis,
    )
    from mastapy._private.system_model.analyses_and_results.stability_analyses.compound._4017 import (
        BoltCompoundStabilityAnalysis,
    )
    from mastapy._private.system_model.analyses_and_results.stability_analyses.compound._4018 import (
        BoltedJointCompoundStabilityAnalysis,
    )
    from mastapy._private.system_model.analyses_and_results.stability_analyses.compound._4019 import (
        ClutchCompoundStabilityAnalysis,
    )
    from mastapy._private.system_model.analyses_and_results.stability_analyses.compound._4020 import (
        ClutchConnectionCompoundStabilityAnalysis,
    )
    from mastapy._private.system_model.analyses_and_results.stability_analyses.compound._4021 import (
        ClutchHalfCompoundStabilityAnalysis,
    )
    from mastapy._private.system_model.analyses_and_results.stability_analyses.compound._4022 import (
        CoaxialConnectionCompoundStabilityAnalysis,
    )
    from mastapy._private.system_model.analyses_and_results.stability_analyses.compound._4023 import (
        ComponentCompoundStabilityAnalysis,
    )
    from mastapy._private.system_model.analyses_and_results.stability_analyses.compound._4024 import (
        ConceptCouplingCompoundStabilityAnalysis,
    )
    from mastapy._private.system_model.analyses_and_results.stability_analyses.compound._4025 import (
        ConceptCouplingConnectionCompoundStabilityAnalysis,
    )
    from mastapy._private.system_model.analyses_and_results.stability_analyses.compound._4026 import (
        ConceptCouplingHalfCompoundStabilityAnalysis,
    )
    from mastapy._private.system_model.analyses_and_results.stability_analyses.compound._4027 import (
        ConceptGearCompoundStabilityAnalysis,
    )
    from mastapy._private.system_model.analyses_and_results.stability_analyses.compound._4028 import (
        ConceptGearMeshCompoundStabilityAnalysis,
    )
    from mastapy._private.system_model.analyses_and_results.stability_analyses.compound._4029 import (
        ConceptGearSetCompoundStabilityAnalysis,
    )
    from mastapy._private.system_model.analyses_and_results.stability_analyses.compound._4030 import (
        ConicalGearCompoundStabilityAnalysis,
    )
    from mastapy._private.system_model.analyses_and_results.stability_analyses.compound._4031 import (
        ConicalGearMeshCompoundStabilityAnalysis,
    )
    from mastapy._private.system_model.analyses_and_results.stability_analyses.compound._4032 import (
        ConicalGearSetCompoundStabilityAnalysis,
    )
    from mastapy._private.system_model.analyses_and_results.stability_analyses.compound._4033 import (
        ConnectionCompoundStabilityAnalysis,
    )
    from mastapy._private.system_model.analyses_and_results.stability_analyses.compound._4034 import (
        ConnectorCompoundStabilityAnalysis,
    )
    from mastapy._private.system_model.analyses_and_results.stability_analyses.compound._4035 import (
        CouplingCompoundStabilityAnalysis,
    )
    from mastapy._private.system_model.analyses_and_results.stability_analyses.compound._4036 import (
        CouplingConnectionCompoundStabilityAnalysis,
    )
    from mastapy._private.system_model.analyses_and_results.stability_analyses.compound._4037 import (
        CouplingHalfCompoundStabilityAnalysis,
    )
    from mastapy._private.system_model.analyses_and_results.stability_analyses.compound._4038 import (
        CVTBeltConnectionCompoundStabilityAnalysis,
    )
    from mastapy._private.system_model.analyses_and_results.stability_analyses.compound._4039 import (
        CVTCompoundStabilityAnalysis,
    )
    from mastapy._private.system_model.analyses_and_results.stability_analyses.compound._4040 import (
        CVTPulleyCompoundStabilityAnalysis,
    )
    from mastapy._private.system_model.analyses_and_results.stability_analyses.compound._4041 import (
        CycloidalAssemblyCompoundStabilityAnalysis,
    )
    from mastapy._private.system_model.analyses_and_results.stability_analyses.compound._4042 import (
        CycloidalDiscCentralBearingConnectionCompoundStabilityAnalysis,
    )
    from mastapy._private.system_model.analyses_and_results.stability_analyses.compound._4043 import (
        CycloidalDiscCompoundStabilityAnalysis,
    )
    from mastapy._private.system_model.analyses_and_results.stability_analyses.compound._4044 import (
        CycloidalDiscPlanetaryBearingConnectionCompoundStabilityAnalysis,
    )
    from mastapy._private.system_model.analyses_and_results.stability_analyses.compound._4045 import (
        CylindricalGearCompoundStabilityAnalysis,
    )
    from mastapy._private.system_model.analyses_and_results.stability_analyses.compound._4046 import (
        CylindricalGearMeshCompoundStabilityAnalysis,
    )
    from mastapy._private.system_model.analyses_and_results.stability_analyses.compound._4047 import (
        CylindricalGearSetCompoundStabilityAnalysis,
    )
    from mastapy._private.system_model.analyses_and_results.stability_analyses.compound._4048 import (
        CylindricalPlanetGearCompoundStabilityAnalysis,
    )
    from mastapy._private.system_model.analyses_and_results.stability_analyses.compound._4049 import (
        DatumCompoundStabilityAnalysis,
    )
    from mastapy._private.system_model.analyses_and_results.stability_analyses.compound._4050 import (
        ExternalCADModelCompoundStabilityAnalysis,
    )
    from mastapy._private.system_model.analyses_and_results.stability_analyses.compound._4051 import (
        FaceGearCompoundStabilityAnalysis,
    )
    from mastapy._private.system_model.analyses_and_results.stability_analyses.compound._4052 import (
        FaceGearMeshCompoundStabilityAnalysis,
    )
    from mastapy._private.system_model.analyses_and_results.stability_analyses.compound._4053 import (
        FaceGearSetCompoundStabilityAnalysis,
    )
    from mastapy._private.system_model.analyses_and_results.stability_analyses.compound._4054 import (
        FEPartCompoundStabilityAnalysis,
    )
    from mastapy._private.system_model.analyses_and_results.stability_analyses.compound._4055 import (
        FlexiblePinAssemblyCompoundStabilityAnalysis,
    )
    from mastapy._private.system_model.analyses_and_results.stability_analyses.compound._4056 import (
        GearCompoundStabilityAnalysis,
    )
    from mastapy._private.system_model.analyses_and_results.stability_analyses.compound._4057 import (
        GearMeshCompoundStabilityAnalysis,
    )
    from mastapy._private.system_model.analyses_and_results.stability_analyses.compound._4058 import (
        GearSetCompoundStabilityAnalysis,
    )
    from mastapy._private.system_model.analyses_and_results.stability_analyses.compound._4059 import (
        GuideDxfModelCompoundStabilityAnalysis,
    )
    from mastapy._private.system_model.analyses_and_results.stability_analyses.compound._4060 import (
        HypoidGearCompoundStabilityAnalysis,
    )
    from mastapy._private.system_model.analyses_and_results.stability_analyses.compound._4061 import (
        HypoidGearMeshCompoundStabilityAnalysis,
    )
    from mastapy._private.system_model.analyses_and_results.stability_analyses.compound._4062 import (
        HypoidGearSetCompoundStabilityAnalysis,
    )
    from mastapy._private.system_model.analyses_and_results.stability_analyses.compound._4063 import (
        InterMountableComponentConnectionCompoundStabilityAnalysis,
    )
    from mastapy._private.system_model.analyses_and_results.stability_analyses.compound._4064 import (
        KlingelnbergCycloPalloidConicalGearCompoundStabilityAnalysis,
    )
    from mastapy._private.system_model.analyses_and_results.stability_analyses.compound._4065 import (
        KlingelnbergCycloPalloidConicalGearMeshCompoundStabilityAnalysis,
    )
    from mastapy._private.system_model.analyses_and_results.stability_analyses.compound._4066 import (
        KlingelnbergCycloPalloidConicalGearSetCompoundStabilityAnalysis,
    )
    from mastapy._private.system_model.analyses_and_results.stability_analyses.compound._4067 import (
        KlingelnbergCycloPalloidHypoidGearCompoundStabilityAnalysis,
    )
    from mastapy._private.system_model.analyses_and_results.stability_analyses.compound._4068 import (
        KlingelnbergCycloPalloidHypoidGearMeshCompoundStabilityAnalysis,
    )
    from mastapy._private.system_model.analyses_and_results.stability_analyses.compound._4069 import (
        KlingelnbergCycloPalloidHypoidGearSetCompoundStabilityAnalysis,
    )
    from mastapy._private.system_model.analyses_and_results.stability_analyses.compound._4070 import (
        KlingelnbergCycloPalloidSpiralBevelGearCompoundStabilityAnalysis,
    )
    from mastapy._private.system_model.analyses_and_results.stability_analyses.compound._4071 import (
        KlingelnbergCycloPalloidSpiralBevelGearMeshCompoundStabilityAnalysis,
    )
    from mastapy._private.system_model.analyses_and_results.stability_analyses.compound._4072 import (
        KlingelnbergCycloPalloidSpiralBevelGearSetCompoundStabilityAnalysis,
    )
    from mastapy._private.system_model.analyses_and_results.stability_analyses.compound._4073 import (
        MassDiscCompoundStabilityAnalysis,
    )
    from mastapy._private.system_model.analyses_and_results.stability_analyses.compound._4074 import (
        MeasurementComponentCompoundStabilityAnalysis,
    )
    from mastapy._private.system_model.analyses_and_results.stability_analyses.compound._4075 import (
        MicrophoneArrayCompoundStabilityAnalysis,
    )
    from mastapy._private.system_model.analyses_and_results.stability_analyses.compound._4076 import (
        MicrophoneCompoundStabilityAnalysis,
    )
    from mastapy._private.system_model.analyses_and_results.stability_analyses.compound._4077 import (
        MountableComponentCompoundStabilityAnalysis,
    )
    from mastapy._private.system_model.analyses_and_results.stability_analyses.compound._4078 import (
        OilSealCompoundStabilityAnalysis,
    )
    from mastapy._private.system_model.analyses_and_results.stability_analyses.compound._4079 import (
        PartCompoundStabilityAnalysis,
    )
    from mastapy._private.system_model.analyses_and_results.stability_analyses.compound._4080 import (
        PartToPartShearCouplingCompoundStabilityAnalysis,
    )
    from mastapy._private.system_model.analyses_and_results.stability_analyses.compound._4081 import (
        PartToPartShearCouplingConnectionCompoundStabilityAnalysis,
    )
    from mastapy._private.system_model.analyses_and_results.stability_analyses.compound._4082 import (
        PartToPartShearCouplingHalfCompoundStabilityAnalysis,
    )
    from mastapy._private.system_model.analyses_and_results.stability_analyses.compound._4083 import (
        PlanetaryConnectionCompoundStabilityAnalysis,
    )
    from mastapy._private.system_model.analyses_and_results.stability_analyses.compound._4084 import (
        PlanetaryGearSetCompoundStabilityAnalysis,
    )
    from mastapy._private.system_model.analyses_and_results.stability_analyses.compound._4085 import (
        PlanetCarrierCompoundStabilityAnalysis,
    )
    from mastapy._private.system_model.analyses_and_results.stability_analyses.compound._4086 import (
        PointLoadCompoundStabilityAnalysis,
    )
    from mastapy._private.system_model.analyses_and_results.stability_analyses.compound._4087 import (
        PowerLoadCompoundStabilityAnalysis,
    )
    from mastapy._private.system_model.analyses_and_results.stability_analyses.compound._4088 import (
        PulleyCompoundStabilityAnalysis,
    )
    from mastapy._private.system_model.analyses_and_results.stability_analyses.compound._4089 import (
        RingPinsCompoundStabilityAnalysis,
    )
    from mastapy._private.system_model.analyses_and_results.stability_analyses.compound._4090 import (
        RingPinsToDiscConnectionCompoundStabilityAnalysis,
    )
    from mastapy._private.system_model.analyses_and_results.stability_analyses.compound._4091 import (
        RollingRingAssemblyCompoundStabilityAnalysis,
    )
    from mastapy._private.system_model.analyses_and_results.stability_analyses.compound._4092 import (
        RollingRingCompoundStabilityAnalysis,
    )
    from mastapy._private.system_model.analyses_and_results.stability_analyses.compound._4093 import (
        RollingRingConnectionCompoundStabilityAnalysis,
    )
    from mastapy._private.system_model.analyses_and_results.stability_analyses.compound._4094 import (
        RootAssemblyCompoundStabilityAnalysis,
    )
    from mastapy._private.system_model.analyses_and_results.stability_analyses.compound._4095 import (
        ShaftCompoundStabilityAnalysis,
    )
    from mastapy._private.system_model.analyses_and_results.stability_analyses.compound._4096 import (
        ShaftHubConnectionCompoundStabilityAnalysis,
    )
    from mastapy._private.system_model.analyses_and_results.stability_analyses.compound._4097 import (
        ShaftToMountableComponentConnectionCompoundStabilityAnalysis,
    )
    from mastapy._private.system_model.analyses_and_results.stability_analyses.compound._4098 import (
        SpecialisedAssemblyCompoundStabilityAnalysis,
    )
    from mastapy._private.system_model.analyses_and_results.stability_analyses.compound._4099 import (
        SpiralBevelGearCompoundStabilityAnalysis,
    )
    from mastapy._private.system_model.analyses_and_results.stability_analyses.compound._4100 import (
        SpiralBevelGearMeshCompoundStabilityAnalysis,
    )
    from mastapy._private.system_model.analyses_and_results.stability_analyses.compound._4101 import (
        SpiralBevelGearSetCompoundStabilityAnalysis,
    )
    from mastapy._private.system_model.analyses_and_results.stability_analyses.compound._4102 import (
        SpringDamperCompoundStabilityAnalysis,
    )
    from mastapy._private.system_model.analyses_and_results.stability_analyses.compound._4103 import (
        SpringDamperConnectionCompoundStabilityAnalysis,
    )
    from mastapy._private.system_model.analyses_and_results.stability_analyses.compound._4104 import (
        SpringDamperHalfCompoundStabilityAnalysis,
    )
    from mastapy._private.system_model.analyses_and_results.stability_analyses.compound._4105 import (
        StraightBevelDiffGearCompoundStabilityAnalysis,
    )
    from mastapy._private.system_model.analyses_and_results.stability_analyses.compound._4106 import (
        StraightBevelDiffGearMeshCompoundStabilityAnalysis,
    )
    from mastapy._private.system_model.analyses_and_results.stability_analyses.compound._4107 import (
        StraightBevelDiffGearSetCompoundStabilityAnalysis,
    )
    from mastapy._private.system_model.analyses_and_results.stability_analyses.compound._4108 import (
        StraightBevelGearCompoundStabilityAnalysis,
    )
    from mastapy._private.system_model.analyses_and_results.stability_analyses.compound._4109 import (
        StraightBevelGearMeshCompoundStabilityAnalysis,
    )
    from mastapy._private.system_model.analyses_and_results.stability_analyses.compound._4110 import (
        StraightBevelGearSetCompoundStabilityAnalysis,
    )
    from mastapy._private.system_model.analyses_and_results.stability_analyses.compound._4111 import (
        StraightBevelPlanetGearCompoundStabilityAnalysis,
    )
    from mastapy._private.system_model.analyses_and_results.stability_analyses.compound._4112 import (
        StraightBevelSunGearCompoundStabilityAnalysis,
    )
    from mastapy._private.system_model.analyses_and_results.stability_analyses.compound._4113 import (
        SynchroniserCompoundStabilityAnalysis,
    )
    from mastapy._private.system_model.analyses_and_results.stability_analyses.compound._4114 import (
        SynchroniserHalfCompoundStabilityAnalysis,
    )
    from mastapy._private.system_model.analyses_and_results.stability_analyses.compound._4115 import (
        SynchroniserPartCompoundStabilityAnalysis,
    )
    from mastapy._private.system_model.analyses_and_results.stability_analyses.compound._4116 import (
        SynchroniserSleeveCompoundStabilityAnalysis,
    )
    from mastapy._private.system_model.analyses_and_results.stability_analyses.compound._4117 import (
        TorqueConverterCompoundStabilityAnalysis,
    )
    from mastapy._private.system_model.analyses_and_results.stability_analyses.compound._4118 import (
        TorqueConverterConnectionCompoundStabilityAnalysis,
    )
    from mastapy._private.system_model.analyses_and_results.stability_analyses.compound._4119 import (
        TorqueConverterPumpCompoundStabilityAnalysis,
    )
    from mastapy._private.system_model.analyses_and_results.stability_analyses.compound._4120 import (
        TorqueConverterTurbineCompoundStabilityAnalysis,
    )
    from mastapy._private.system_model.analyses_and_results.stability_analyses.compound._4121 import (
        UnbalancedMassCompoundStabilityAnalysis,
    )
    from mastapy._private.system_model.analyses_and_results.stability_analyses.compound._4122 import (
        VirtualComponentCompoundStabilityAnalysis,
    )
    from mastapy._private.system_model.analyses_and_results.stability_analyses.compound._4123 import (
        WormGearCompoundStabilityAnalysis,
    )
    from mastapy._private.system_model.analyses_and_results.stability_analyses.compound._4124 import (
        WormGearMeshCompoundStabilityAnalysis,
    )
    from mastapy._private.system_model.analyses_and_results.stability_analyses.compound._4125 import (
        WormGearSetCompoundStabilityAnalysis,
    )
    from mastapy._private.system_model.analyses_and_results.stability_analyses.compound._4126 import (
        ZerolBevelGearCompoundStabilityAnalysis,
    )
    from mastapy._private.system_model.analyses_and_results.stability_analyses.compound._4127 import (
        ZerolBevelGearMeshCompoundStabilityAnalysis,
    )
    from mastapy._private.system_model.analyses_and_results.stability_analyses.compound._4128 import (
        ZerolBevelGearSetCompoundStabilityAnalysis,
    )
else:
    import sys as __sys

    from lazy_imports import LazyImporter as __LazyImporter

    __import_structure = {
        "_private.system_model.analyses_and_results.stability_analyses.compound._3998": [
            "AbstractAssemblyCompoundStabilityAnalysis"
        ],
        "_private.system_model.analyses_and_results.stability_analyses.compound._3999": [
            "AbstractShaftCompoundStabilityAnalysis"
        ],
        "_private.system_model.analyses_and_results.stability_analyses.compound._4000": [
            "AbstractShaftOrHousingCompoundStabilityAnalysis"
        ],
        "_private.system_model.analyses_and_results.stability_analyses.compound._4001": [
            "AbstractShaftToMountableComponentConnectionCompoundStabilityAnalysis"
        ],
        "_private.system_model.analyses_and_results.stability_analyses.compound._4002": [
            "AGMAGleasonConicalGearCompoundStabilityAnalysis"
        ],
        "_private.system_model.analyses_and_results.stability_analyses.compound._4003": [
            "AGMAGleasonConicalGearMeshCompoundStabilityAnalysis"
        ],
        "_private.system_model.analyses_and_results.stability_analyses.compound._4004": [
            "AGMAGleasonConicalGearSetCompoundStabilityAnalysis"
        ],
        "_private.system_model.analyses_and_results.stability_analyses.compound._4005": [
            "AssemblyCompoundStabilityAnalysis"
        ],
        "_private.system_model.analyses_and_results.stability_analyses.compound._4006": [
            "BearingCompoundStabilityAnalysis"
        ],
        "_private.system_model.analyses_and_results.stability_analyses.compound._4007": [
            "BeltConnectionCompoundStabilityAnalysis"
        ],
        "_private.system_model.analyses_and_results.stability_analyses.compound._4008": [
            "BeltDriveCompoundStabilityAnalysis"
        ],
        "_private.system_model.analyses_and_results.stability_analyses.compound._4009": [
            "BevelDifferentialGearCompoundStabilityAnalysis"
        ],
        "_private.system_model.analyses_and_results.stability_analyses.compound._4010": [
            "BevelDifferentialGearMeshCompoundStabilityAnalysis"
        ],
        "_private.system_model.analyses_and_results.stability_analyses.compound._4011": [
            "BevelDifferentialGearSetCompoundStabilityAnalysis"
        ],
        "_private.system_model.analyses_and_results.stability_analyses.compound._4012": [
            "BevelDifferentialPlanetGearCompoundStabilityAnalysis"
        ],
        "_private.system_model.analyses_and_results.stability_analyses.compound._4013": [
            "BevelDifferentialSunGearCompoundStabilityAnalysis"
        ],
        "_private.system_model.analyses_and_results.stability_analyses.compound._4014": [
            "BevelGearCompoundStabilityAnalysis"
        ],
        "_private.system_model.analyses_and_results.stability_analyses.compound._4015": [
            "BevelGearMeshCompoundStabilityAnalysis"
        ],
        "_private.system_model.analyses_and_results.stability_analyses.compound._4016": [
            "BevelGearSetCompoundStabilityAnalysis"
        ],
        "_private.system_model.analyses_and_results.stability_analyses.compound._4017": [
            "BoltCompoundStabilityAnalysis"
        ],
        "_private.system_model.analyses_and_results.stability_analyses.compound._4018": [
            "BoltedJointCompoundStabilityAnalysis"
        ],
        "_private.system_model.analyses_and_results.stability_analyses.compound._4019": [
            "ClutchCompoundStabilityAnalysis"
        ],
        "_private.system_model.analyses_and_results.stability_analyses.compound._4020": [
            "ClutchConnectionCompoundStabilityAnalysis"
        ],
        "_private.system_model.analyses_and_results.stability_analyses.compound._4021": [
            "ClutchHalfCompoundStabilityAnalysis"
        ],
        "_private.system_model.analyses_and_results.stability_analyses.compound._4022": [
            "CoaxialConnectionCompoundStabilityAnalysis"
        ],
        "_private.system_model.analyses_and_results.stability_analyses.compound._4023": [
            "ComponentCompoundStabilityAnalysis"
        ],
        "_private.system_model.analyses_and_results.stability_analyses.compound._4024": [
            "ConceptCouplingCompoundStabilityAnalysis"
        ],
        "_private.system_model.analyses_and_results.stability_analyses.compound._4025": [
            "ConceptCouplingConnectionCompoundStabilityAnalysis"
        ],
        "_private.system_model.analyses_and_results.stability_analyses.compound._4026": [
            "ConceptCouplingHalfCompoundStabilityAnalysis"
        ],
        "_private.system_model.analyses_and_results.stability_analyses.compound._4027": [
            "ConceptGearCompoundStabilityAnalysis"
        ],
        "_private.system_model.analyses_and_results.stability_analyses.compound._4028": [
            "ConceptGearMeshCompoundStabilityAnalysis"
        ],
        "_private.system_model.analyses_and_results.stability_analyses.compound._4029": [
            "ConceptGearSetCompoundStabilityAnalysis"
        ],
        "_private.system_model.analyses_and_results.stability_analyses.compound._4030": [
            "ConicalGearCompoundStabilityAnalysis"
        ],
        "_private.system_model.analyses_and_results.stability_analyses.compound._4031": [
            "ConicalGearMeshCompoundStabilityAnalysis"
        ],
        "_private.system_model.analyses_and_results.stability_analyses.compound._4032": [
            "ConicalGearSetCompoundStabilityAnalysis"
        ],
        "_private.system_model.analyses_and_results.stability_analyses.compound._4033": [
            "ConnectionCompoundStabilityAnalysis"
        ],
        "_private.system_model.analyses_and_results.stability_analyses.compound._4034": [
            "ConnectorCompoundStabilityAnalysis"
        ],
        "_private.system_model.analyses_and_results.stability_analyses.compound._4035": [
            "CouplingCompoundStabilityAnalysis"
        ],
        "_private.system_model.analyses_and_results.stability_analyses.compound._4036": [
            "CouplingConnectionCompoundStabilityAnalysis"
        ],
        "_private.system_model.analyses_and_results.stability_analyses.compound._4037": [
            "CouplingHalfCompoundStabilityAnalysis"
        ],
        "_private.system_model.analyses_and_results.stability_analyses.compound._4038": [
            "CVTBeltConnectionCompoundStabilityAnalysis"
        ],
        "_private.system_model.analyses_and_results.stability_analyses.compound._4039": [
            "CVTCompoundStabilityAnalysis"
        ],
        "_private.system_model.analyses_and_results.stability_analyses.compound._4040": [
            "CVTPulleyCompoundStabilityAnalysis"
        ],
        "_private.system_model.analyses_and_results.stability_analyses.compound._4041": [
            "CycloidalAssemblyCompoundStabilityAnalysis"
        ],
        "_private.system_model.analyses_and_results.stability_analyses.compound._4042": [
            "CycloidalDiscCentralBearingConnectionCompoundStabilityAnalysis"
        ],
        "_private.system_model.analyses_and_results.stability_analyses.compound._4043": [
            "CycloidalDiscCompoundStabilityAnalysis"
        ],
        "_private.system_model.analyses_and_results.stability_analyses.compound._4044": [
            "CycloidalDiscPlanetaryBearingConnectionCompoundStabilityAnalysis"
        ],
        "_private.system_model.analyses_and_results.stability_analyses.compound._4045": [
            "CylindricalGearCompoundStabilityAnalysis"
        ],
        "_private.system_model.analyses_and_results.stability_analyses.compound._4046": [
            "CylindricalGearMeshCompoundStabilityAnalysis"
        ],
        "_private.system_model.analyses_and_results.stability_analyses.compound._4047": [
            "CylindricalGearSetCompoundStabilityAnalysis"
        ],
        "_private.system_model.analyses_and_results.stability_analyses.compound._4048": [
            "CylindricalPlanetGearCompoundStabilityAnalysis"
        ],
        "_private.system_model.analyses_and_results.stability_analyses.compound._4049": [
            "DatumCompoundStabilityAnalysis"
        ],
        "_private.system_model.analyses_and_results.stability_analyses.compound._4050": [
            "ExternalCADModelCompoundStabilityAnalysis"
        ],
        "_private.system_model.analyses_and_results.stability_analyses.compound._4051": [
            "FaceGearCompoundStabilityAnalysis"
        ],
        "_private.system_model.analyses_and_results.stability_analyses.compound._4052": [
            "FaceGearMeshCompoundStabilityAnalysis"
        ],
        "_private.system_model.analyses_and_results.stability_analyses.compound._4053": [
            "FaceGearSetCompoundStabilityAnalysis"
        ],
        "_private.system_model.analyses_and_results.stability_analyses.compound._4054": [
            "FEPartCompoundStabilityAnalysis"
        ],
        "_private.system_model.analyses_and_results.stability_analyses.compound._4055": [
            "FlexiblePinAssemblyCompoundStabilityAnalysis"
        ],
        "_private.system_model.analyses_and_results.stability_analyses.compound._4056": [
            "GearCompoundStabilityAnalysis"
        ],
        "_private.system_model.analyses_and_results.stability_analyses.compound._4057": [
            "GearMeshCompoundStabilityAnalysis"
        ],
        "_private.system_model.analyses_and_results.stability_analyses.compound._4058": [
            "GearSetCompoundStabilityAnalysis"
        ],
        "_private.system_model.analyses_and_results.stability_analyses.compound._4059": [
            "GuideDxfModelCompoundStabilityAnalysis"
        ],
        "_private.system_model.analyses_and_results.stability_analyses.compound._4060": [
            "HypoidGearCompoundStabilityAnalysis"
        ],
        "_private.system_model.analyses_and_results.stability_analyses.compound._4061": [
            "HypoidGearMeshCompoundStabilityAnalysis"
        ],
        "_private.system_model.analyses_and_results.stability_analyses.compound._4062": [
            "HypoidGearSetCompoundStabilityAnalysis"
        ],
        "_private.system_model.analyses_and_results.stability_analyses.compound._4063": [
            "InterMountableComponentConnectionCompoundStabilityAnalysis"
        ],
        "_private.system_model.analyses_and_results.stability_analyses.compound._4064": [
            "KlingelnbergCycloPalloidConicalGearCompoundStabilityAnalysis"
        ],
        "_private.system_model.analyses_and_results.stability_analyses.compound._4065": [
            "KlingelnbergCycloPalloidConicalGearMeshCompoundStabilityAnalysis"
        ],
        "_private.system_model.analyses_and_results.stability_analyses.compound._4066": [
            "KlingelnbergCycloPalloidConicalGearSetCompoundStabilityAnalysis"
        ],
        "_private.system_model.analyses_and_results.stability_analyses.compound._4067": [
            "KlingelnbergCycloPalloidHypoidGearCompoundStabilityAnalysis"
        ],
        "_private.system_model.analyses_and_results.stability_analyses.compound._4068": [
            "KlingelnbergCycloPalloidHypoidGearMeshCompoundStabilityAnalysis"
        ],
        "_private.system_model.analyses_and_results.stability_analyses.compound._4069": [
            "KlingelnbergCycloPalloidHypoidGearSetCompoundStabilityAnalysis"
        ],
        "_private.system_model.analyses_and_results.stability_analyses.compound._4070": [
            "KlingelnbergCycloPalloidSpiralBevelGearCompoundStabilityAnalysis"
        ],
        "_private.system_model.analyses_and_results.stability_analyses.compound._4071": [
            "KlingelnbergCycloPalloidSpiralBevelGearMeshCompoundStabilityAnalysis"
        ],
        "_private.system_model.analyses_and_results.stability_analyses.compound._4072": [
            "KlingelnbergCycloPalloidSpiralBevelGearSetCompoundStabilityAnalysis"
        ],
        "_private.system_model.analyses_and_results.stability_analyses.compound._4073": [
            "MassDiscCompoundStabilityAnalysis"
        ],
        "_private.system_model.analyses_and_results.stability_analyses.compound._4074": [
            "MeasurementComponentCompoundStabilityAnalysis"
        ],
        "_private.system_model.analyses_and_results.stability_analyses.compound._4075": [
            "MicrophoneArrayCompoundStabilityAnalysis"
        ],
        "_private.system_model.analyses_and_results.stability_analyses.compound._4076": [
            "MicrophoneCompoundStabilityAnalysis"
        ],
        "_private.system_model.analyses_and_results.stability_analyses.compound._4077": [
            "MountableComponentCompoundStabilityAnalysis"
        ],
        "_private.system_model.analyses_and_results.stability_analyses.compound._4078": [
            "OilSealCompoundStabilityAnalysis"
        ],
        "_private.system_model.analyses_and_results.stability_analyses.compound._4079": [
            "PartCompoundStabilityAnalysis"
        ],
        "_private.system_model.analyses_and_results.stability_analyses.compound._4080": [
            "PartToPartShearCouplingCompoundStabilityAnalysis"
        ],
        "_private.system_model.analyses_and_results.stability_analyses.compound._4081": [
            "PartToPartShearCouplingConnectionCompoundStabilityAnalysis"
        ],
        "_private.system_model.analyses_and_results.stability_analyses.compound._4082": [
            "PartToPartShearCouplingHalfCompoundStabilityAnalysis"
        ],
        "_private.system_model.analyses_and_results.stability_analyses.compound._4083": [
            "PlanetaryConnectionCompoundStabilityAnalysis"
        ],
        "_private.system_model.analyses_and_results.stability_analyses.compound._4084": [
            "PlanetaryGearSetCompoundStabilityAnalysis"
        ],
        "_private.system_model.analyses_and_results.stability_analyses.compound._4085": [
            "PlanetCarrierCompoundStabilityAnalysis"
        ],
        "_private.system_model.analyses_and_results.stability_analyses.compound._4086": [
            "PointLoadCompoundStabilityAnalysis"
        ],
        "_private.system_model.analyses_and_results.stability_analyses.compound._4087": [
            "PowerLoadCompoundStabilityAnalysis"
        ],
        "_private.system_model.analyses_and_results.stability_analyses.compound._4088": [
            "PulleyCompoundStabilityAnalysis"
        ],
        "_private.system_model.analyses_and_results.stability_analyses.compound._4089": [
            "RingPinsCompoundStabilityAnalysis"
        ],
        "_private.system_model.analyses_and_results.stability_analyses.compound._4090": [
            "RingPinsToDiscConnectionCompoundStabilityAnalysis"
        ],
        "_private.system_model.analyses_and_results.stability_analyses.compound._4091": [
            "RollingRingAssemblyCompoundStabilityAnalysis"
        ],
        "_private.system_model.analyses_and_results.stability_analyses.compound._4092": [
            "RollingRingCompoundStabilityAnalysis"
        ],
        "_private.system_model.analyses_and_results.stability_analyses.compound._4093": [
            "RollingRingConnectionCompoundStabilityAnalysis"
        ],
        "_private.system_model.analyses_and_results.stability_analyses.compound._4094": [
            "RootAssemblyCompoundStabilityAnalysis"
        ],
        "_private.system_model.analyses_and_results.stability_analyses.compound._4095": [
            "ShaftCompoundStabilityAnalysis"
        ],
        "_private.system_model.analyses_and_results.stability_analyses.compound._4096": [
            "ShaftHubConnectionCompoundStabilityAnalysis"
        ],
        "_private.system_model.analyses_and_results.stability_analyses.compound._4097": [
            "ShaftToMountableComponentConnectionCompoundStabilityAnalysis"
        ],
        "_private.system_model.analyses_and_results.stability_analyses.compound._4098": [
            "SpecialisedAssemblyCompoundStabilityAnalysis"
        ],
        "_private.system_model.analyses_and_results.stability_analyses.compound._4099": [
            "SpiralBevelGearCompoundStabilityAnalysis"
        ],
        "_private.system_model.analyses_and_results.stability_analyses.compound._4100": [
            "SpiralBevelGearMeshCompoundStabilityAnalysis"
        ],
        "_private.system_model.analyses_and_results.stability_analyses.compound._4101": [
            "SpiralBevelGearSetCompoundStabilityAnalysis"
        ],
        "_private.system_model.analyses_and_results.stability_analyses.compound._4102": [
            "SpringDamperCompoundStabilityAnalysis"
        ],
        "_private.system_model.analyses_and_results.stability_analyses.compound._4103": [
            "SpringDamperConnectionCompoundStabilityAnalysis"
        ],
        "_private.system_model.analyses_and_results.stability_analyses.compound._4104": [
            "SpringDamperHalfCompoundStabilityAnalysis"
        ],
        "_private.system_model.analyses_and_results.stability_analyses.compound._4105": [
            "StraightBevelDiffGearCompoundStabilityAnalysis"
        ],
        "_private.system_model.analyses_and_results.stability_analyses.compound._4106": [
            "StraightBevelDiffGearMeshCompoundStabilityAnalysis"
        ],
        "_private.system_model.analyses_and_results.stability_analyses.compound._4107": [
            "StraightBevelDiffGearSetCompoundStabilityAnalysis"
        ],
        "_private.system_model.analyses_and_results.stability_analyses.compound._4108": [
            "StraightBevelGearCompoundStabilityAnalysis"
        ],
        "_private.system_model.analyses_and_results.stability_analyses.compound._4109": [
            "StraightBevelGearMeshCompoundStabilityAnalysis"
        ],
        "_private.system_model.analyses_and_results.stability_analyses.compound._4110": [
            "StraightBevelGearSetCompoundStabilityAnalysis"
        ],
        "_private.system_model.analyses_and_results.stability_analyses.compound._4111": [
            "StraightBevelPlanetGearCompoundStabilityAnalysis"
        ],
        "_private.system_model.analyses_and_results.stability_analyses.compound._4112": [
            "StraightBevelSunGearCompoundStabilityAnalysis"
        ],
        "_private.system_model.analyses_and_results.stability_analyses.compound._4113": [
            "SynchroniserCompoundStabilityAnalysis"
        ],
        "_private.system_model.analyses_and_results.stability_analyses.compound._4114": [
            "SynchroniserHalfCompoundStabilityAnalysis"
        ],
        "_private.system_model.analyses_and_results.stability_analyses.compound._4115": [
            "SynchroniserPartCompoundStabilityAnalysis"
        ],
        "_private.system_model.analyses_and_results.stability_analyses.compound._4116": [
            "SynchroniserSleeveCompoundStabilityAnalysis"
        ],
        "_private.system_model.analyses_and_results.stability_analyses.compound._4117": [
            "TorqueConverterCompoundStabilityAnalysis"
        ],
        "_private.system_model.analyses_and_results.stability_analyses.compound._4118": [
            "TorqueConverterConnectionCompoundStabilityAnalysis"
        ],
        "_private.system_model.analyses_and_results.stability_analyses.compound._4119": [
            "TorqueConverterPumpCompoundStabilityAnalysis"
        ],
        "_private.system_model.analyses_and_results.stability_analyses.compound._4120": [
            "TorqueConverterTurbineCompoundStabilityAnalysis"
        ],
        "_private.system_model.analyses_and_results.stability_analyses.compound._4121": [
            "UnbalancedMassCompoundStabilityAnalysis"
        ],
        "_private.system_model.analyses_and_results.stability_analyses.compound._4122": [
            "VirtualComponentCompoundStabilityAnalysis"
        ],
        "_private.system_model.analyses_and_results.stability_analyses.compound._4123": [
            "WormGearCompoundStabilityAnalysis"
        ],
        "_private.system_model.analyses_and_results.stability_analyses.compound._4124": [
            "WormGearMeshCompoundStabilityAnalysis"
        ],
        "_private.system_model.analyses_and_results.stability_analyses.compound._4125": [
            "WormGearSetCompoundStabilityAnalysis"
        ],
        "_private.system_model.analyses_and_results.stability_analyses.compound._4126": [
            "ZerolBevelGearCompoundStabilityAnalysis"
        ],
        "_private.system_model.analyses_and_results.stability_analyses.compound._4127": [
            "ZerolBevelGearMeshCompoundStabilityAnalysis"
        ],
        "_private.system_model.analyses_and_results.stability_analyses.compound._4128": [
            "ZerolBevelGearSetCompoundStabilityAnalysis"
        ],
    }

    __sys.modules[__name__] = __LazyImporter(
        "mastapy",
        globals()["__file__"],
        __import_structure,
    )

__all__ = (
    "AbstractAssemblyCompoundStabilityAnalysis",
    "AbstractShaftCompoundStabilityAnalysis",
    "AbstractShaftOrHousingCompoundStabilityAnalysis",
    "AbstractShaftToMountableComponentConnectionCompoundStabilityAnalysis",
    "AGMAGleasonConicalGearCompoundStabilityAnalysis",
    "AGMAGleasonConicalGearMeshCompoundStabilityAnalysis",
    "AGMAGleasonConicalGearSetCompoundStabilityAnalysis",
    "AssemblyCompoundStabilityAnalysis",
    "BearingCompoundStabilityAnalysis",
    "BeltConnectionCompoundStabilityAnalysis",
    "BeltDriveCompoundStabilityAnalysis",
    "BevelDifferentialGearCompoundStabilityAnalysis",
    "BevelDifferentialGearMeshCompoundStabilityAnalysis",
    "BevelDifferentialGearSetCompoundStabilityAnalysis",
    "BevelDifferentialPlanetGearCompoundStabilityAnalysis",
    "BevelDifferentialSunGearCompoundStabilityAnalysis",
    "BevelGearCompoundStabilityAnalysis",
    "BevelGearMeshCompoundStabilityAnalysis",
    "BevelGearSetCompoundStabilityAnalysis",
    "BoltCompoundStabilityAnalysis",
    "BoltedJointCompoundStabilityAnalysis",
    "ClutchCompoundStabilityAnalysis",
    "ClutchConnectionCompoundStabilityAnalysis",
    "ClutchHalfCompoundStabilityAnalysis",
    "CoaxialConnectionCompoundStabilityAnalysis",
    "ComponentCompoundStabilityAnalysis",
    "ConceptCouplingCompoundStabilityAnalysis",
    "ConceptCouplingConnectionCompoundStabilityAnalysis",
    "ConceptCouplingHalfCompoundStabilityAnalysis",
    "ConceptGearCompoundStabilityAnalysis",
    "ConceptGearMeshCompoundStabilityAnalysis",
    "ConceptGearSetCompoundStabilityAnalysis",
    "ConicalGearCompoundStabilityAnalysis",
    "ConicalGearMeshCompoundStabilityAnalysis",
    "ConicalGearSetCompoundStabilityAnalysis",
    "ConnectionCompoundStabilityAnalysis",
    "ConnectorCompoundStabilityAnalysis",
    "CouplingCompoundStabilityAnalysis",
    "CouplingConnectionCompoundStabilityAnalysis",
    "CouplingHalfCompoundStabilityAnalysis",
    "CVTBeltConnectionCompoundStabilityAnalysis",
    "CVTCompoundStabilityAnalysis",
    "CVTPulleyCompoundStabilityAnalysis",
    "CycloidalAssemblyCompoundStabilityAnalysis",
    "CycloidalDiscCentralBearingConnectionCompoundStabilityAnalysis",
    "CycloidalDiscCompoundStabilityAnalysis",
    "CycloidalDiscPlanetaryBearingConnectionCompoundStabilityAnalysis",
    "CylindricalGearCompoundStabilityAnalysis",
    "CylindricalGearMeshCompoundStabilityAnalysis",
    "CylindricalGearSetCompoundStabilityAnalysis",
    "CylindricalPlanetGearCompoundStabilityAnalysis",
    "DatumCompoundStabilityAnalysis",
    "ExternalCADModelCompoundStabilityAnalysis",
    "FaceGearCompoundStabilityAnalysis",
    "FaceGearMeshCompoundStabilityAnalysis",
    "FaceGearSetCompoundStabilityAnalysis",
    "FEPartCompoundStabilityAnalysis",
    "FlexiblePinAssemblyCompoundStabilityAnalysis",
    "GearCompoundStabilityAnalysis",
    "GearMeshCompoundStabilityAnalysis",
    "GearSetCompoundStabilityAnalysis",
    "GuideDxfModelCompoundStabilityAnalysis",
    "HypoidGearCompoundStabilityAnalysis",
    "HypoidGearMeshCompoundStabilityAnalysis",
    "HypoidGearSetCompoundStabilityAnalysis",
    "InterMountableComponentConnectionCompoundStabilityAnalysis",
    "KlingelnbergCycloPalloidConicalGearCompoundStabilityAnalysis",
    "KlingelnbergCycloPalloidConicalGearMeshCompoundStabilityAnalysis",
    "KlingelnbergCycloPalloidConicalGearSetCompoundStabilityAnalysis",
    "KlingelnbergCycloPalloidHypoidGearCompoundStabilityAnalysis",
    "KlingelnbergCycloPalloidHypoidGearMeshCompoundStabilityAnalysis",
    "KlingelnbergCycloPalloidHypoidGearSetCompoundStabilityAnalysis",
    "KlingelnbergCycloPalloidSpiralBevelGearCompoundStabilityAnalysis",
    "KlingelnbergCycloPalloidSpiralBevelGearMeshCompoundStabilityAnalysis",
    "KlingelnbergCycloPalloidSpiralBevelGearSetCompoundStabilityAnalysis",
    "MassDiscCompoundStabilityAnalysis",
    "MeasurementComponentCompoundStabilityAnalysis",
    "MicrophoneArrayCompoundStabilityAnalysis",
    "MicrophoneCompoundStabilityAnalysis",
    "MountableComponentCompoundStabilityAnalysis",
    "OilSealCompoundStabilityAnalysis",
    "PartCompoundStabilityAnalysis",
    "PartToPartShearCouplingCompoundStabilityAnalysis",
    "PartToPartShearCouplingConnectionCompoundStabilityAnalysis",
    "PartToPartShearCouplingHalfCompoundStabilityAnalysis",
    "PlanetaryConnectionCompoundStabilityAnalysis",
    "PlanetaryGearSetCompoundStabilityAnalysis",
    "PlanetCarrierCompoundStabilityAnalysis",
    "PointLoadCompoundStabilityAnalysis",
    "PowerLoadCompoundStabilityAnalysis",
    "PulleyCompoundStabilityAnalysis",
    "RingPinsCompoundStabilityAnalysis",
    "RingPinsToDiscConnectionCompoundStabilityAnalysis",
    "RollingRingAssemblyCompoundStabilityAnalysis",
    "RollingRingCompoundStabilityAnalysis",
    "RollingRingConnectionCompoundStabilityAnalysis",
    "RootAssemblyCompoundStabilityAnalysis",
    "ShaftCompoundStabilityAnalysis",
    "ShaftHubConnectionCompoundStabilityAnalysis",
    "ShaftToMountableComponentConnectionCompoundStabilityAnalysis",
    "SpecialisedAssemblyCompoundStabilityAnalysis",
    "SpiralBevelGearCompoundStabilityAnalysis",
    "SpiralBevelGearMeshCompoundStabilityAnalysis",
    "SpiralBevelGearSetCompoundStabilityAnalysis",
    "SpringDamperCompoundStabilityAnalysis",
    "SpringDamperConnectionCompoundStabilityAnalysis",
    "SpringDamperHalfCompoundStabilityAnalysis",
    "StraightBevelDiffGearCompoundStabilityAnalysis",
    "StraightBevelDiffGearMeshCompoundStabilityAnalysis",
    "StraightBevelDiffGearSetCompoundStabilityAnalysis",
    "StraightBevelGearCompoundStabilityAnalysis",
    "StraightBevelGearMeshCompoundStabilityAnalysis",
    "StraightBevelGearSetCompoundStabilityAnalysis",
    "StraightBevelPlanetGearCompoundStabilityAnalysis",
    "StraightBevelSunGearCompoundStabilityAnalysis",
    "SynchroniserCompoundStabilityAnalysis",
    "SynchroniserHalfCompoundStabilityAnalysis",
    "SynchroniserPartCompoundStabilityAnalysis",
    "SynchroniserSleeveCompoundStabilityAnalysis",
    "TorqueConverterCompoundStabilityAnalysis",
    "TorqueConverterConnectionCompoundStabilityAnalysis",
    "TorqueConverterPumpCompoundStabilityAnalysis",
    "TorqueConverterTurbineCompoundStabilityAnalysis",
    "UnbalancedMassCompoundStabilityAnalysis",
    "VirtualComponentCompoundStabilityAnalysis",
    "WormGearCompoundStabilityAnalysis",
    "WormGearMeshCompoundStabilityAnalysis",
    "WormGearSetCompoundStabilityAnalysis",
    "ZerolBevelGearCompoundStabilityAnalysis",
    "ZerolBevelGearMeshCompoundStabilityAnalysis",
    "ZerolBevelGearSetCompoundStabilityAnalysis",
)



"""RedressingSettings"""
from __future__ import annotations

from typing import TYPE_CHECKING, ClassVar, Generic, TypeVar

from PIL.Image import Image

from mastapy._private._internal.dataclasses import extended_dataclass
from mastapy._private._internal.type_enforcement import enforce_parameter_types
from mastapy._private._internal.implicit import overridable
from mastapy._private._internal.overridable_constructor import _unpack_overridable
from mastapy._private._internal import constructor, conversion, utility
from mastapy._private import _0
from mastapy._private._internal.cast_exception import CastException
from mastapy._private._internal.python_net import python_net_import

_REDRESSING_SETTINGS = python_net_import(
    "SMT.MastaAPI.Gears.Manufacturing.Cylindrical.AxialAndPlungeShavingDynamics",
    "RedressingSettings",
)

if TYPE_CHECKING:
    from typing import Any, Type, Union, Tuple, List

    from mastapy._private.gears.manufacturing.cylindrical.cutters import _738
    from mastapy._private.gears.manufacturing.cylindrical.axial_and_plunge_shaving_dynamics import (
        _788,
    )

    Self = TypeVar("Self", bound="RedressingSettings")
    CastSelf = TypeVar("CastSelf", bound="RedressingSettings._Cast_RedressingSettings")

T = TypeVar("T", bound="_788.ShavingDynamics")

__docformat__ = "restructuredtext en"
__all__ = ("RedressingSettings",)


@extended_dataclass(frozen=True, slots=True, weakref_slot=True)
class _Cast_RedressingSettings:
    """Special nested class for casting RedressingSettings to subclasses."""

    __parent__: "RedressingSettings"

    @property
    def redressing_settings(self: "CastSelf") -> "RedressingSettings":
        return self.__parent__

    def __getattr__(self: "CastSelf", name: str) -> "Any":
        try:
            return self.__getattribute__(name)
        except AttributeError:
            class_name = utility.camel(name)
            raise CastException(
                f'Detected an invalid cast. Cannot cast to type "{class_name}"'
            ) from None


@extended_dataclass(frozen=True, slots=True, weakref_slot=True)
class RedressingSettings(_0.APIBase, Generic[T]):
    """RedressingSettings

    This is a mastapy class.

    Generic Types:
        T
    """

    TYPE: ClassVar["Type"] = _REDRESSING_SETTINGS

    wrapped: "Any"

    def __post_init__(self: "Self") -> None:
        """Override of the post initialisation magic method."""
        if not hasattr(self.wrapped, "reference_count"):
            self.wrapped.reference_count = 0

        self.wrapped.reference_count += 1

    @property
    def centre_distance(self: "Self") -> "overridable.Overridable_float":
        """Overridable[float]

        Note:
            This property is readonly.
        """
        temp = self.wrapped.CentreDistance

        if temp is None:
            return 0.0

        return constructor.new_from_mastapy(
            "mastapy._private._internal.implicit.overridable", "Overridable_float"
        )(temp)

    @property
    def icon(self: "Self") -> "Image":
        """Image

        Note:
            This property is readonly.
        """
        temp = self.wrapped.Icon

        if temp is None:
            return None

        value = conversion.pn_to_mp_smt_bitmap(temp)

        if value is None:
            return None

        return value

    @property
    def name(self: "Self") -> "str":
        """str

        Note:
            This property is readonly.
        """
        temp = self.wrapped.Name

        if temp is None:
            return ""

        return temp

    @property
    def normal_thickness_at_reference_diameter(self: "Self") -> "float":
        """float

        Note:
            This property is readonly.
        """
        temp = self.wrapped.NormalThicknessAtReferenceDiameter

        if temp is None:
            return 0.0

        return temp

    @property
    def operating_normal_pressure_angle(self: "Self") -> "float":
        """float

        Note:
            This property is readonly.
        """
        temp = self.wrapped.OperatingNormalPressureAngle

        if temp is None:
            return 0.0

        return temp

    @property
    def selected(self: "Self") -> "bool":
        """bool"""
        temp = self.wrapped.Selected

        if temp is None:
            return False

        return temp

    @selected.setter
    @enforce_parameter_types
    def selected(self: "Self", value: "bool") -> None:
        self.wrapped.Selected = bool(value) if value is not None else False

    @property
    def shaft_angle(self: "Self") -> "overridable.Overridable_float":
        """Overridable[float]"""
        temp = self.wrapped.ShaftAngle

        if temp is None:
            return 0.0

        return constructor.new_from_mastapy(
            "mastapy._private._internal.implicit.overridable", "Overridable_float"
        )(temp)

    @shaft_angle.setter
    @enforce_parameter_types
    def shaft_angle(self: "Self", value: "Union[float, Tuple[float, bool]]") -> None:
        wrapper_type = overridable.Overridable_float.wrapper_type()
        enclosed_type = overridable.Overridable_float.implicit_type()
        value, is_overridden = _unpack_overridable(value)
        value = wrapper_type[enclosed_type](
            enclosed_type(value) if value is not None else 0.0, is_overridden
        )
        self.wrapped.ShaftAngle = value

    @property
    def shaver_maximum_eap_diameter(self: "Self") -> "float":
        """float

        Note:
            This property is readonly.
        """
        temp = self.wrapped.ShaverMaximumEAPDiameter

        if temp is None:
            return 0.0

        return temp

    @property
    def shaver_minimum_sap_diameter(self: "Self") -> "float":
        """float

        Note:
            This property is readonly.
        """
        temp = self.wrapped.ShaverMinimumSAPDiameter

        if temp is None:
            return 0.0

        return temp

    @property
    def shaver_tip_diameter(self: "Self") -> "float":
        """float

        Note:
            This property is readonly.
        """
        temp = self.wrapped.ShaverTipDiameter

        if temp is None:
            return 0.0

        return temp

    @property
    def shaver_tip_thickness(self: "Self") -> "float":
        """float

        Note:
            This property is readonly.
        """
        temp = self.wrapped.ShaverTipThickness

        if temp is None:
            return 0.0

        return temp

    @property
    def shaving_status(self: "Self") -> "str":
        """str

        Note:
            This property is readonly.
        """
        temp = self.wrapped.ShavingStatus

        if temp is None:
            return ""

        return temp

    @property
    def redressed_shaver(self: "Self") -> "_738.CylindricalGearShaver":
        """mastapy._private.gears.manufacturing.cylindrical.cutters.CylindricalGearShaver

        Note:
            This property is readonly.
        """
        temp = self.wrapped.RedressedShaver

        if temp is None:
            return None

        type_ = temp.GetType()
        return constructor.new(type_.Namespace, type_.Name)(temp)

    @property
    def report_names(self: "Self") -> "List[str]":
        """List[str]

        Note:
            This property is readonly.
        """
        temp = self.wrapped.ReportNames

        if temp is None:
            return None

        value = conversion.pn_to_mp_objects_in_list(temp, str)

        if value is None:
            return None

        return value

    @enforce_parameter_types
    def output_default_report_to(self: "Self", file_path: "str") -> None:
        """Method does not return.

        Args:
            file_path (str)
        """
        file_path = str(file_path)
        self.wrapped.OutputDefaultReportTo(file_path if file_path else "")

    def get_default_report_with_encoded_images(self: "Self") -> "str":
        """str"""
        method_result = self.wrapped.GetDefaultReportWithEncodedImages()
        return method_result

    @enforce_parameter_types
    def output_active_report_to(self: "Self", file_path: "str") -> None:
        """Method does not return.

        Args:
            file_path (str)
        """
        file_path = str(file_path)
        self.wrapped.OutputActiveReportTo(file_path if file_path else "")

    @enforce_parameter_types
    def output_active_report_as_text_to(self: "Self", file_path: "str") -> None:
        """Method does not return.

        Args:
            file_path (str)
        """
        file_path = str(file_path)
        self.wrapped.OutputActiveReportAsTextTo(file_path if file_path else "")

    def get_active_report_with_encoded_images(self: "Self") -> "str":
        """str"""
        method_result = self.wrapped.GetActiveReportWithEncodedImages()
        return method_result

    @enforce_parameter_types
    def output_named_report_to(
        self: "Self", report_name: "str", file_path: "str"
    ) -> None:
        """Method does not return.

        Args:
            report_name (str)
            file_path (str)
        """
        report_name = str(report_name)
        file_path = str(file_path)
        self.wrapped.OutputNamedReportTo(
            report_name if report_name else "", file_path if file_path else ""
        )

    @enforce_parameter_types
    def output_named_report_as_masta_report(
        self: "Self", report_name: "str", file_path: "str"
    ) -> None:
        """Method does not return.

        Args:
            report_name (str)
            file_path (str)
        """
        report_name = str(report_name)
        file_path = str(file_path)
        self.wrapped.OutputNamedReportAsMastaReport(
            report_name if report_name else "", file_path if file_path else ""
        )

    @enforce_parameter_types
    def output_named_report_as_text_to(
        self: "Self", report_name: "str", file_path: "str"
    ) -> None:
        """Method does not return.

        Args:
            report_name (str)
            file_path (str)
        """
        report_name = str(report_name)
        file_path = str(file_path)
        self.wrapped.OutputNamedReportAsTextTo(
            report_name if report_name else "", file_path if file_path else ""
        )

    @enforce_parameter_types
    def get_named_report_with_encoded_images(self: "Self", report_name: "str") -> "str":
        """str

        Args:
            report_name (str)
        """
        report_name = str(report_name)
        method_result = self.wrapped.GetNamedReportWithEncodedImages(
            report_name if report_name else ""
        )
        return method_result

    @property
    def cast_to(self: "Self") -> "_Cast_RedressingSettings":
        """Cast to another type.

        Returns:
            _Cast_RedressingSettings
        """
        return _Cast_RedressingSettings(self)



"""MountableComponentModalAnalysis"""
from __future__ import annotations

from typing import TYPE_CHECKING, ClassVar

from mastapy._private._internal.dataclasses import extended_dataclass
from mastapy._private._internal import constructor, utility
from mastapy._private.system_model.analyses_and_results.modal_analyses import _4708
from mastapy._private._internal.cast_exception import CastException
from mastapy._private._internal.python_net import python_net_import

_MOUNTABLE_COMPONENT_MODAL_ANALYSIS = python_net_import(
    "SMT.MastaAPI.SystemModel.AnalysesAndResults.ModalAnalyses",
    "MountableComponentModalAnalysis",
)

if TYPE_CHECKING:
    from typing import Any, Type, TypeVar

    from mastapy._private.system_model.part_model import _2520
    from mastapy._private.system_model.analyses_and_results.system_deflections import (
        _2867,
    )
    from mastapy._private.system_model.analyses_and_results.modal_analyses import (
        _4688,
        _4691,
        _4695,
        _4697,
        _4698,
        _4700,
        _4705,
        _4710,
        _4713,
        _4716,
        _4719,
        _4722,
        _4726,
        _4732,
        _4734,
        _4741,
        _4747,
        _4751,
        _4755,
        _4758,
        _4761,
        _4763,
        _4764,
        _4773,
        _4777,
        _4781,
        _4782,
        _4783,
        _4784,
        _4785,
        _4789,
        _4791,
        _4797,
        _4800,
        _4803,
        _4806,
        _4808,
        _4809,
        _4810,
        _4812,
        _4813,
        _4816,
        _4817,
        _4818,
        _4819,
        _4824,
        _4827,
        _4775,
    )
    from mastapy._private.system_model.analyses_and_results.analysis_cases import (
        _7713,
        _7710,
    )
    from mastapy._private.system_model.analyses_and_results import _2740, _2736, _2734

    Self = TypeVar("Self", bound="MountableComponentModalAnalysis")
    CastSelf = TypeVar(
        "CastSelf",
        bound="MountableComponentModalAnalysis._Cast_MountableComponentModalAnalysis",
    )


__docformat__ = "restructuredtext en"
__all__ = ("MountableComponentModalAnalysis",)


@extended_dataclass(frozen=True, slots=True, weakref_slot=True)
class _Cast_MountableComponentModalAnalysis:
    """Special nested class for casting MountableComponentModalAnalysis to subclasses."""

    __parent__: "MountableComponentModalAnalysis"

    @property
    def component_modal_analysis(self: "CastSelf") -> "_4708.ComponentModalAnalysis":
        return self.__parent__._cast(_4708.ComponentModalAnalysis)

    @property
    def part_modal_analysis(self: "CastSelf") -> "_4775.PartModalAnalysis":
        from mastapy._private.system_model.analyses_and_results.modal_analyses import (
            _4775,
        )

        return self.__parent__._cast(_4775.PartModalAnalysis)

    @property
    def part_static_load_analysis_case(
        self: "CastSelf",
    ) -> "_7713.PartStaticLoadAnalysisCase":
        from mastapy._private.system_model.analyses_and_results.analysis_cases import (
            _7713,
        )

        return self.__parent__._cast(_7713.PartStaticLoadAnalysisCase)

    @property
    def part_analysis_case(self: "CastSelf") -> "_7710.PartAnalysisCase":
        from mastapy._private.system_model.analyses_and_results.analysis_cases import (
            _7710,
        )

        return self.__parent__._cast(_7710.PartAnalysisCase)

    @property
    def part_analysis(self: "CastSelf") -> "_2740.PartAnalysis":
        from mastapy._private.system_model.analyses_and_results import _2740

        return self.__parent__._cast(_2740.PartAnalysis)

    @property
    def design_entity_single_context_analysis(
        self: "CastSelf",
    ) -> "_2736.DesignEntitySingleContextAnalysis":
        from mastapy._private.system_model.analyses_and_results import _2736

        return self.__parent__._cast(_2736.DesignEntitySingleContextAnalysis)

    @property
    def design_entity_analysis(self: "CastSelf") -> "_2734.DesignEntityAnalysis":
        from mastapy._private.system_model.analyses_and_results import _2734

        return self.__parent__._cast(_2734.DesignEntityAnalysis)

    @property
    def agma_gleason_conical_gear_modal_analysis(
        self: "CastSelf",
    ) -> "_4688.AGMAGleasonConicalGearModalAnalysis":
        from mastapy._private.system_model.analyses_and_results.modal_analyses import (
            _4688,
        )

        return self.__parent__._cast(_4688.AGMAGleasonConicalGearModalAnalysis)

    @property
    def bearing_modal_analysis(self: "CastSelf") -> "_4691.BearingModalAnalysis":
        from mastapy._private.system_model.analyses_and_results.modal_analyses import (
            _4691,
        )

        return self.__parent__._cast(_4691.BearingModalAnalysis)

    @property
    def bevel_differential_gear_modal_analysis(
        self: "CastSelf",
    ) -> "_4695.BevelDifferentialGearModalAnalysis":
        from mastapy._private.system_model.analyses_and_results.modal_analyses import (
            _4695,
        )

        return self.__parent__._cast(_4695.BevelDifferentialGearModalAnalysis)

    @property
    def bevel_differential_planet_gear_modal_analysis(
        self: "CastSelf",
    ) -> "_4697.BevelDifferentialPlanetGearModalAnalysis":
        from mastapy._private.system_model.analyses_and_results.modal_analyses import (
            _4697,
        )

        return self.__parent__._cast(_4697.BevelDifferentialPlanetGearModalAnalysis)

    @property
    def bevel_differential_sun_gear_modal_analysis(
        self: "CastSelf",
    ) -> "_4698.BevelDifferentialSunGearModalAnalysis":
        from mastapy._private.system_model.analyses_and_results.modal_analyses import (
            _4698,
        )

        return self.__parent__._cast(_4698.BevelDifferentialSunGearModalAnalysis)

    @property
    def bevel_gear_modal_analysis(self: "CastSelf") -> "_4700.BevelGearModalAnalysis":
        from mastapy._private.system_model.analyses_and_results.modal_analyses import (
            _4700,
        )

        return self.__parent__._cast(_4700.BevelGearModalAnalysis)

    @property
    def clutch_half_modal_analysis(self: "CastSelf") -> "_4705.ClutchHalfModalAnalysis":
        from mastapy._private.system_model.analyses_and_results.modal_analyses import (
            _4705,
        )

        return self.__parent__._cast(_4705.ClutchHalfModalAnalysis)

    @property
    def concept_coupling_half_modal_analysis(
        self: "CastSelf",
    ) -> "_4710.ConceptCouplingHalfModalAnalysis":
        from mastapy._private.system_model.analyses_and_results.modal_analyses import (
            _4710,
        )

        return self.__parent__._cast(_4710.ConceptCouplingHalfModalAnalysis)

    @property
    def concept_gear_modal_analysis(
        self: "CastSelf",
    ) -> "_4713.ConceptGearModalAnalysis":
        from mastapy._private.system_model.analyses_and_results.modal_analyses import (
            _4713,
        )

        return self.__parent__._cast(_4713.ConceptGearModalAnalysis)

    @property
    def conical_gear_modal_analysis(
        self: "CastSelf",
    ) -> "_4716.ConicalGearModalAnalysis":
        from mastapy._private.system_model.analyses_and_results.modal_analyses import (
            _4716,
        )

        return self.__parent__._cast(_4716.ConicalGearModalAnalysis)

    @property
    def connector_modal_analysis(self: "CastSelf") -> "_4719.ConnectorModalAnalysis":
        from mastapy._private.system_model.analyses_and_results.modal_analyses import (
            _4719,
        )

        return self.__parent__._cast(_4719.ConnectorModalAnalysis)

    @property
    def coupling_half_modal_analysis(
        self: "CastSelf",
    ) -> "_4722.CouplingHalfModalAnalysis":
        from mastapy._private.system_model.analyses_and_results.modal_analyses import (
            _4722,
        )

        return self.__parent__._cast(_4722.CouplingHalfModalAnalysis)

    @property
    def cvt_pulley_modal_analysis(self: "CastSelf") -> "_4726.CVTPulleyModalAnalysis":
        from mastapy._private.system_model.analyses_and_results.modal_analyses import (
            _4726,
        )

        return self.__parent__._cast(_4726.CVTPulleyModalAnalysis)

    @property
    def cylindrical_gear_modal_analysis(
        self: "CastSelf",
    ) -> "_4732.CylindricalGearModalAnalysis":
        from mastapy._private.system_model.analyses_and_results.modal_analyses import (
            _4732,
        )

        return self.__parent__._cast(_4732.CylindricalGearModalAnalysis)

    @property
    def cylindrical_planet_gear_modal_analysis(
        self: "CastSelf",
    ) -> "_4734.CylindricalPlanetGearModalAnalysis":
        from mastapy._private.system_model.analyses_and_results.modal_analyses import (
            _4734,
        )

        return self.__parent__._cast(_4734.CylindricalPlanetGearModalAnalysis)

    @property
    def face_gear_modal_analysis(self: "CastSelf") -> "_4741.FaceGearModalAnalysis":
        from mastapy._private.system_model.analyses_and_results.modal_analyses import (
            _4741,
        )

        return self.__parent__._cast(_4741.FaceGearModalAnalysis)

    @property
    def gear_modal_analysis(self: "CastSelf") -> "_4747.GearModalAnalysis":
        from mastapy._private.system_model.analyses_and_results.modal_analyses import (
            _4747,
        )

        return self.__parent__._cast(_4747.GearModalAnalysis)

    @property
    def hypoid_gear_modal_analysis(self: "CastSelf") -> "_4751.HypoidGearModalAnalysis":
        from mastapy._private.system_model.analyses_and_results.modal_analyses import (
            _4751,
        )

        return self.__parent__._cast(_4751.HypoidGearModalAnalysis)

    @property
    def klingelnberg_cyclo_palloid_conical_gear_modal_analysis(
        self: "CastSelf",
    ) -> "_4755.KlingelnbergCycloPalloidConicalGearModalAnalysis":
        from mastapy._private.system_model.analyses_and_results.modal_analyses import (
            _4755,
        )

        return self.__parent__._cast(
            _4755.KlingelnbergCycloPalloidConicalGearModalAnalysis
        )

    @property
    def klingelnberg_cyclo_palloid_hypoid_gear_modal_analysis(
        self: "CastSelf",
    ) -> "_4758.KlingelnbergCycloPalloidHypoidGearModalAnalysis":
        from mastapy._private.system_model.analyses_and_results.modal_analyses import (
            _4758,
        )

        return self.__parent__._cast(
            _4758.KlingelnbergCycloPalloidHypoidGearModalAnalysis
        )

    @property
    def klingelnberg_cyclo_palloid_spiral_bevel_gear_modal_analysis(
        self: "CastSelf",
    ) -> "_4761.KlingelnbergCycloPalloidSpiralBevelGearModalAnalysis":
        from mastapy._private.system_model.analyses_and_results.modal_analyses import (
            _4761,
        )

        return self.__parent__._cast(
            _4761.KlingelnbergCycloPalloidSpiralBevelGearModalAnalysis
        )

    @property
    def mass_disc_modal_analysis(self: "CastSelf") -> "_4763.MassDiscModalAnalysis":
        from mastapy._private.system_model.analyses_and_results.modal_analyses import (
            _4763,
        )

        return self.__parent__._cast(_4763.MassDiscModalAnalysis)

    @property
    def measurement_component_modal_analysis(
        self: "CastSelf",
    ) -> "_4764.MeasurementComponentModalAnalysis":
        from mastapy._private.system_model.analyses_and_results.modal_analyses import (
            _4764,
        )

        return self.__parent__._cast(_4764.MeasurementComponentModalAnalysis)

    @property
    def oil_seal_modal_analysis(self: "CastSelf") -> "_4773.OilSealModalAnalysis":
        from mastapy._private.system_model.analyses_and_results.modal_analyses import (
            _4773,
        )

        return self.__parent__._cast(_4773.OilSealModalAnalysis)

    @property
    def part_to_part_shear_coupling_half_modal_analysis(
        self: "CastSelf",
    ) -> "_4777.PartToPartShearCouplingHalfModalAnalysis":
        from mastapy._private.system_model.analyses_and_results.modal_analyses import (
            _4777,
        )

        return self.__parent__._cast(_4777.PartToPartShearCouplingHalfModalAnalysis)

    @property
    def planet_carrier_modal_analysis(
        self: "CastSelf",
    ) -> "_4781.PlanetCarrierModalAnalysis":
        from mastapy._private.system_model.analyses_and_results.modal_analyses import (
            _4781,
        )

        return self.__parent__._cast(_4781.PlanetCarrierModalAnalysis)

    @property
    def point_load_modal_analysis(self: "CastSelf") -> "_4782.PointLoadModalAnalysis":
        from mastapy._private.system_model.analyses_and_results.modal_analyses import (
            _4782,
        )

        return self.__parent__._cast(_4782.PointLoadModalAnalysis)

    @property
    def power_load_modal_analysis(self: "CastSelf") -> "_4783.PowerLoadModalAnalysis":
        from mastapy._private.system_model.analyses_and_results.modal_analyses import (
            _4783,
        )

        return self.__parent__._cast(_4783.PowerLoadModalAnalysis)

    @property
    def pulley_modal_analysis(self: "CastSelf") -> "_4784.PulleyModalAnalysis":
        from mastapy._private.system_model.analyses_and_results.modal_analyses import (
            _4784,
        )

        return self.__parent__._cast(_4784.PulleyModalAnalysis)

    @property
    def ring_pins_modal_analysis(self: "CastSelf") -> "_4785.RingPinsModalAnalysis":
        from mastapy._private.system_model.analyses_and_results.modal_analyses import (
            _4785,
        )

        return self.__parent__._cast(_4785.RingPinsModalAnalysis)

    @property
    def rolling_ring_modal_analysis(
        self: "CastSelf",
    ) -> "_4789.RollingRingModalAnalysis":
        from mastapy._private.system_model.analyses_and_results.modal_analyses import (
            _4789,
        )

        return self.__parent__._cast(_4789.RollingRingModalAnalysis)

    @property
    def shaft_hub_connection_modal_analysis(
        self: "CastSelf",
    ) -> "_4791.ShaftHubConnectionModalAnalysis":
        from mastapy._private.system_model.analyses_and_results.modal_analyses import (
            _4791,
        )

        return self.__parent__._cast(_4791.ShaftHubConnectionModalAnalysis)

    @property
    def spiral_bevel_gear_modal_analysis(
        self: "CastSelf",
    ) -> "_4797.SpiralBevelGearModalAnalysis":
        from mastapy._private.system_model.analyses_and_results.modal_analyses import (
            _4797,
        )

        return self.__parent__._cast(_4797.SpiralBevelGearModalAnalysis)

    @property
    def spring_damper_half_modal_analysis(
        self: "CastSelf",
    ) -> "_4800.SpringDamperHalfModalAnalysis":
        from mastapy._private.system_model.analyses_and_results.modal_analyses import (
            _4800,
        )

        return self.__parent__._cast(_4800.SpringDamperHalfModalAnalysis)

    @property
    def straight_bevel_diff_gear_modal_analysis(
        self: "CastSelf",
    ) -> "_4803.StraightBevelDiffGearModalAnalysis":
        from mastapy._private.system_model.analyses_and_results.modal_analyses import (
            _4803,
        )

        return self.__parent__._cast(_4803.StraightBevelDiffGearModalAnalysis)

    @property
    def straight_bevel_gear_modal_analysis(
        self: "CastSelf",
    ) -> "_4806.StraightBevelGearModalAnalysis":
        from mastapy._private.system_model.analyses_and_results.modal_analyses import (
            _4806,
        )

        return self.__parent__._cast(_4806.StraightBevelGearModalAnalysis)

    @property
    def straight_bevel_planet_gear_modal_analysis(
        self: "CastSelf",
    ) -> "_4808.StraightBevelPlanetGearModalAnalysis":
        from mastapy._private.system_model.analyses_and_results.modal_analyses import (
            _4808,
        )

        return self.__parent__._cast(_4808.StraightBevelPlanetGearModalAnalysis)

    @property
    def straight_bevel_sun_gear_modal_analysis(
        self: "CastSelf",
    ) -> "_4809.StraightBevelSunGearModalAnalysis":
        from mastapy._private.system_model.analyses_and_results.modal_analyses import (
            _4809,
        )

        return self.__parent__._cast(_4809.StraightBevelSunGearModalAnalysis)

    @property
    def synchroniser_half_modal_analysis(
        self: "CastSelf",
    ) -> "_4810.SynchroniserHalfModalAnalysis":
        from mastapy._private.system_model.analyses_and_results.modal_analyses import (
            _4810,
        )

        return self.__parent__._cast(_4810.SynchroniserHalfModalAnalysis)

    @property
    def synchroniser_part_modal_analysis(
        self: "CastSelf",
    ) -> "_4812.SynchroniserPartModalAnalysis":
        from mastapy._private.system_model.analyses_and_results.modal_analyses import (
            _4812,
        )

        return self.__parent__._cast(_4812.SynchroniserPartModalAnalysis)

    @property
    def synchroniser_sleeve_modal_analysis(
        self: "CastSelf",
    ) -> "_4813.SynchroniserSleeveModalAnalysis":
        from mastapy._private.system_model.analyses_and_results.modal_analyses import (
            _4813,
        )

        return self.__parent__._cast(_4813.SynchroniserSleeveModalAnalysis)

    @property
    def torque_converter_pump_modal_analysis(
        self: "CastSelf",
    ) -> "_4816.TorqueConverterPumpModalAnalysis":
        from mastapy._private.system_model.analyses_and_results.modal_analyses import (
            _4816,
        )

        return self.__parent__._cast(_4816.TorqueConverterPumpModalAnalysis)

    @property
    def torque_converter_turbine_modal_analysis(
        self: "CastSelf",
    ) -> "_4817.TorqueConverterTurbineModalAnalysis":
        from mastapy._private.system_model.analyses_and_results.modal_analyses import (
            _4817,
        )

        return self.__parent__._cast(_4817.TorqueConverterTurbineModalAnalysis)

    @property
    def unbalanced_mass_modal_analysis(
        self: "CastSelf",
    ) -> "_4818.UnbalancedMassModalAnalysis":
        from mastapy._private.system_model.analyses_and_results.modal_analyses import (
            _4818,
        )

        return self.__parent__._cast(_4818.UnbalancedMassModalAnalysis)

    @property
    def virtual_component_modal_analysis(
        self: "CastSelf",
    ) -> "_4819.VirtualComponentModalAnalysis":
        from mastapy._private.system_model.analyses_and_results.modal_analyses import (
            _4819,
        )

        return self.__parent__._cast(_4819.VirtualComponentModalAnalysis)

    @property
    def worm_gear_modal_analysis(self: "CastSelf") -> "_4824.WormGearModalAnalysis":
        from mastapy._private.system_model.analyses_and_results.modal_analyses import (
            _4824,
        )

        return self.__parent__._cast(_4824.WormGearModalAnalysis)

    @property
    def zerol_bevel_gear_modal_analysis(
        self: "CastSelf",
    ) -> "_4827.ZerolBevelGearModalAnalysis":
        from mastapy._private.system_model.analyses_and_results.modal_analyses import (
            _4827,
        )

        return self.__parent__._cast(_4827.ZerolBevelGearModalAnalysis)

    @property
    def mountable_component_modal_analysis(
        self: "CastSelf",
    ) -> "MountableComponentModalAnalysis":
        return self.__parent__

    def __getattr__(self: "CastSelf", name: str) -> "Any":
        try:
            return self.__getattribute__(name)
        except AttributeError:
            class_name = utility.camel(name)
            raise CastException(
                f'Detected an invalid cast. Cannot cast to type "{class_name}"'
            ) from None


@extended_dataclass(frozen=True, slots=True, weakref_slot=True)
class MountableComponentModalAnalysis(_4708.ComponentModalAnalysis):
    """MountableComponentModalAnalysis

    This is a mastapy class.
    """

    TYPE: ClassVar["Type"] = _MOUNTABLE_COMPONENT_MODAL_ANALYSIS

    wrapped: "Any"

    def __post_init__(self: "Self") -> None:
        """Override of the post initialisation magic method."""
        if not hasattr(self.wrapped, "reference_count"):
            self.wrapped.reference_count = 0

        self.wrapped.reference_count += 1

    @property
    def component_design(self: "Self") -> "_2520.MountableComponent":
        """mastapy._private.system_model.part_model.MountableComponent

        Note:
            This property is readonly.
        """
        temp = self.wrapped.ComponentDesign

        if temp is None:
            return None

        type_ = temp.GetType()
        return constructor.new(type_.Namespace, type_.Name)(temp)

    @property
    def system_deflection_results(
        self: "Self",
    ) -> "_2867.MountableComponentSystemDeflection":
        """mastapy._private.system_model.analyses_and_results.system_deflections.MountableComponentSystemDeflection

        Note:
            This property is readonly.
        """
        temp = self.wrapped.SystemDeflectionResults

        if temp is None:
            return None

        type_ = temp.GetType()
        return constructor.new(type_.Namespace, type_.Name)(temp)

    @property
    def cast_to(self: "Self") -> "_Cast_MountableComponentModalAnalysis":
        """Cast to another type.

        Returns:
            _Cast_MountableComponentModalAnalysis
        """
        return _Cast_MountableComponentModalAnalysis(self)



"""Subpackage."""

from typing import TYPE_CHECKING as __tc


if __tc:
    from mastapy._private.system_model.connections_and_sockets._2318 import (
        AbstractShaftToMountableComponentConnection,
    )
    from mastapy._private.system_model.connections_and_sockets._2319 import (
        BearingInnerSocket,
    )
    from mastapy._private.system_model.connections_and_sockets._2320 import (
        BearingOuterSocket,
    )
    from mastapy._private.system_model.connections_and_sockets._2321 import (
        BeltConnection,
    )
    from mastapy._private.system_model.connections_and_sockets._2322 import (
        CoaxialConnection,
    )
    from mastapy._private.system_model.connections_and_sockets._2323 import (
        ComponentConnection,
    )
    from mastapy._private.system_model.connections_and_sockets._2324 import (
        ComponentMeasurer,
    )
    from mastapy._private.system_model.connections_and_sockets._2325 import Connection
    from mastapy._private.system_model.connections_and_sockets._2326 import (
        CVTBeltConnection,
    )
    from mastapy._private.system_model.connections_and_sockets._2327 import (
        CVTPulleySocket,
    )
    from mastapy._private.system_model.connections_and_sockets._2328 import (
        CylindricalComponentConnection,
    )
    from mastapy._private.system_model.connections_and_sockets._2329 import (
        CylindricalSocket,
    )
    from mastapy._private.system_model.connections_and_sockets._2330 import (
        DatumMeasurement,
    )
    from mastapy._private.system_model.connections_and_sockets._2331 import (
        ElectricMachineStatorSocket,
    )
    from mastapy._private.system_model.connections_and_sockets._2332 import (
        InnerShaftSocket,
    )
    from mastapy._private.system_model.connections_and_sockets._2333 import (
        InnerShaftSocketBase,
    )
    from mastapy._private.system_model.connections_and_sockets._2334 import (
        InterMountableComponentConnection,
    )
    from mastapy._private.system_model.connections_and_sockets._2335 import (
        MountableComponentInnerSocket,
    )
    from mastapy._private.system_model.connections_and_sockets._2336 import (
        MountableComponentOuterSocket,
    )
    from mastapy._private.system_model.connections_and_sockets._2337 import (
        MountableComponentSocket,
    )
    from mastapy._private.system_model.connections_and_sockets._2338 import (
        OuterShaftSocket,
    )
    from mastapy._private.system_model.connections_and_sockets._2339 import (
        OuterShaftSocketBase,
    )
    from mastapy._private.system_model.connections_and_sockets._2340 import (
        PlanetaryConnection,
    )
    from mastapy._private.system_model.connections_and_sockets._2341 import (
        PlanetarySocket,
    )
    from mastapy._private.system_model.connections_and_sockets._2342 import (
        PlanetarySocketBase,
    )
    from mastapy._private.system_model.connections_and_sockets._2343 import PulleySocket
    from mastapy._private.system_model.connections_and_sockets._2344 import (
        RealignmentResult,
    )
    from mastapy._private.system_model.connections_and_sockets._2345 import (
        RollingRingConnection,
    )
    from mastapy._private.system_model.connections_and_sockets._2346 import (
        RollingRingSocket,
    )
    from mastapy._private.system_model.connections_and_sockets._2347 import ShaftSocket
    from mastapy._private.system_model.connections_and_sockets._2348 import (
        ShaftToMountableComponentConnection,
    )
    from mastapy._private.system_model.connections_and_sockets._2349 import Socket
    from mastapy._private.system_model.connections_and_sockets._2350 import (
        SocketConnectionOptions,
    )
    from mastapy._private.system_model.connections_and_sockets._2351 import (
        SocketConnectionSelection,
    )
else:
    import sys as __sys

    from lazy_imports import LazyImporter as __LazyImporter

    __import_structure = {
        "_private.system_model.connections_and_sockets._2318": [
            "AbstractShaftToMountableComponentConnection"
        ],
        "_private.system_model.connections_and_sockets._2319": ["BearingInnerSocket"],
        "_private.system_model.connections_and_sockets._2320": ["BearingOuterSocket"],
        "_private.system_model.connections_and_sockets._2321": ["BeltConnection"],
        "_private.system_model.connections_and_sockets._2322": ["CoaxialConnection"],
        "_private.system_model.connections_and_sockets._2323": ["ComponentConnection"],
        "_private.system_model.connections_and_sockets._2324": ["ComponentMeasurer"],
        "_private.system_model.connections_and_sockets._2325": ["Connection"],
        "_private.system_model.connections_and_sockets._2326": ["CVTBeltConnection"],
        "_private.system_model.connections_and_sockets._2327": ["CVTPulleySocket"],
        "_private.system_model.connections_and_sockets._2328": [
            "CylindricalComponentConnection"
        ],
        "_private.system_model.connections_and_sockets._2329": ["CylindricalSocket"],
        "_private.system_model.connections_and_sockets._2330": ["DatumMeasurement"],
        "_private.system_model.connections_and_sockets._2331": [
            "ElectricMachineStatorSocket"
        ],
        "_private.system_model.connections_and_sockets._2332": ["InnerShaftSocket"],
        "_private.system_model.connections_and_sockets._2333": ["InnerShaftSocketBase"],
        "_private.system_model.connections_and_sockets._2334": [
            "InterMountableComponentConnection"
        ],
        "_private.system_model.connections_and_sockets._2335": [
            "MountableComponentInnerSocket"
        ],
        "_private.system_model.connections_and_sockets._2336": [
            "MountableComponentOuterSocket"
        ],
        "_private.system_model.connections_and_sockets._2337": [
            "MountableComponentSocket"
        ],
        "_private.system_model.connections_and_sockets._2338": ["OuterShaftSocket"],
        "_private.system_model.connections_and_sockets._2339": ["OuterShaftSocketBase"],
        "_private.system_model.connections_and_sockets._2340": ["PlanetaryConnection"],
        "_private.system_model.connections_and_sockets._2341": ["PlanetarySocket"],
        "_private.system_model.connections_and_sockets._2342": ["PlanetarySocketBase"],
        "_private.system_model.connections_and_sockets._2343": ["PulleySocket"],
        "_private.system_model.connections_and_sockets._2344": ["RealignmentResult"],
        "_private.system_model.connections_and_sockets._2345": [
            "RollingRingConnection"
        ],
        "_private.system_model.connections_and_sockets._2346": ["RollingRingSocket"],
        "_private.system_model.connections_and_sockets._2347": ["ShaftSocket"],
        "_private.system_model.connections_and_sockets._2348": [
            "ShaftToMountableComponentConnection"
        ],
        "_private.system_model.connections_and_sockets._2349": ["Socket"],
        "_private.system_model.connections_and_sockets._2350": [
            "SocketConnectionOptions"
        ],
        "_private.system_model.connections_and_sockets._2351": [
            "SocketConnectionSelection"
        ],
    }

    __sys.modules[__name__] = __LazyImporter(
        "mastapy",
        globals()["__file__"],
        __import_structure,
    )

__all__ = (
    "AbstractShaftToMountableComponentConnection",
    "BearingInnerSocket",
    "BearingOuterSocket",
    "BeltConnection",
    "CoaxialConnection",
    "ComponentConnection",
    "ComponentMeasurer",
    "Connection",
    "CVTBeltConnection",
    "CVTPulleySocket",
    "CylindricalComponentConnection",
    "CylindricalSocket",
    "DatumMeasurement",
    "ElectricMachineStatorSocket",
    "InnerShaftSocket",
    "InnerShaftSocketBase",
    "InterMountableComponentConnection",
    "MountableComponentInnerSocket",
    "MountableComponentOuterSocket",
    "MountableComponentSocket",
    "OuterShaftSocket",
    "OuterShaftSocketBase",
    "PlanetaryConnection",
    "PlanetarySocket",
    "PlanetarySocketBase",
    "PulleySocket",
    "RealignmentResult",
    "RollingRingConnection",
    "RollingRingSocket",
    "ShaftSocket",
    "ShaftToMountableComponentConnection",
    "Socket",
    "SocketConnectionOptions",
    "SocketConnectionSelection",
)



"""GearMeshRating"""
from __future__ import annotations

from typing import TYPE_CHECKING, ClassVar

from mastapy._private._internal.dataclasses import extended_dataclass
from mastapy._private._internal import constructor, utility
from mastapy._private.gears.rating import _363
from mastapy._private._internal.cast_exception import CastException
from mastapy._private._internal.python_net import python_net_import

_GEAR_MESH_RATING = python_net_import("SMT.MastaAPI.Gears.Rating", "GearMeshRating")

if TYPE_CHECKING:
    from typing import Any, Type, TypeVar

    from mastapy._private.gears.load_case import _898
    from mastapy._private.gears.rating.zerol_bevel import _380
    from mastapy._private.gears.rating.worm import _384
    from mastapy._private.gears.rating.straight_bevel import _406
    from mastapy._private.gears.rating.straight_bevel_diff import _409
    from mastapy._private.gears.rating.spiral_bevel import _413
    from mastapy._private.gears.rating.klingelnberg_spiral_bevel import _416
    from mastapy._private.gears.rating.klingelnberg_hypoid import _419
    from mastapy._private.gears.rating.klingelnberg_conical import _422
    from mastapy._private.gears.rating.hypoid import _449
    from mastapy._private.gears.rating.face import _458
    from mastapy._private.gears.rating.cylindrical import _469
    from mastapy._private.gears.rating.conical import _550
    from mastapy._private.gears.rating.concept import _561
    from mastapy._private.gears.rating.bevel import _565
    from mastapy._private.gears.rating.agma_gleason_conical import _576
    from mastapy._private.gears.analysis import _1254

    Self = TypeVar("Self", bound="GearMeshRating")
    CastSelf = TypeVar("CastSelf", bound="GearMeshRating._Cast_GearMeshRating")


__docformat__ = "restructuredtext en"
__all__ = ("GearMeshRating",)


@extended_dataclass(frozen=True, slots=True, weakref_slot=True)
class _Cast_GearMeshRating:
    """Special nested class for casting GearMeshRating to subclasses."""

    __parent__: "GearMeshRating"

    @property
    def abstract_gear_mesh_rating(self: "CastSelf") -> "_363.AbstractGearMeshRating":
        return self.__parent__._cast(_363.AbstractGearMeshRating)

    @property
    def abstract_gear_mesh_analysis(
        self: "CastSelf",
    ) -> "_1254.AbstractGearMeshAnalysis":
        from mastapy._private.gears.analysis import _1254

        return self.__parent__._cast(_1254.AbstractGearMeshAnalysis)

    @property
    def zerol_bevel_gear_mesh_rating(
        self: "CastSelf",
    ) -> "_380.ZerolBevelGearMeshRating":
        from mastapy._private.gears.rating.zerol_bevel import _380

        return self.__parent__._cast(_380.ZerolBevelGearMeshRating)

    @property
    def worm_gear_mesh_rating(self: "CastSelf") -> "_384.WormGearMeshRating":
        from mastapy._private.gears.rating.worm import _384

        return self.__parent__._cast(_384.WormGearMeshRating)

    @property
    def straight_bevel_gear_mesh_rating(
        self: "CastSelf",
    ) -> "_406.StraightBevelGearMeshRating":
        from mastapy._private.gears.rating.straight_bevel import _406

        return self.__parent__._cast(_406.StraightBevelGearMeshRating)

    @property
    def straight_bevel_diff_gear_mesh_rating(
        self: "CastSelf",
    ) -> "_409.StraightBevelDiffGearMeshRating":
        from mastapy._private.gears.rating.straight_bevel_diff import _409

        return self.__parent__._cast(_409.StraightBevelDiffGearMeshRating)

    @property
    def spiral_bevel_gear_mesh_rating(
        self: "CastSelf",
    ) -> "_413.SpiralBevelGearMeshRating":
        from mastapy._private.gears.rating.spiral_bevel import _413

        return self.__parent__._cast(_413.SpiralBevelGearMeshRating)

    @property
    def klingelnberg_cyclo_palloid_spiral_bevel_gear_mesh_rating(
        self: "CastSelf",
    ) -> "_416.KlingelnbergCycloPalloidSpiralBevelGearMeshRating":
        from mastapy._private.gears.rating.klingelnberg_spiral_bevel import _416

        return self.__parent__._cast(
            _416.KlingelnbergCycloPalloidSpiralBevelGearMeshRating
        )

    @property
    def klingelnberg_cyclo_palloid_hypoid_gear_mesh_rating(
        self: "CastSelf",
    ) -> "_419.KlingelnbergCycloPalloidHypoidGearMeshRating":
        from mastapy._private.gears.rating.klingelnberg_hypoid import _419

        return self.__parent__._cast(_419.KlingelnbergCycloPalloidHypoidGearMeshRating)

    @property
    def klingelnberg_cyclo_palloid_conical_gear_mesh_rating(
        self: "CastSelf",
    ) -> "_422.KlingelnbergCycloPalloidConicalGearMeshRating":
        from mastapy._private.gears.rating.klingelnberg_conical import _422

        return self.__parent__._cast(_422.KlingelnbergCycloPalloidConicalGearMeshRating)

    @property
    def hypoid_gear_mesh_rating(self: "CastSelf") -> "_449.HypoidGearMeshRating":
        from mastapy._private.gears.rating.hypoid import _449

        return self.__parent__._cast(_449.HypoidGearMeshRating)

    @property
    def face_gear_mesh_rating(self: "CastSelf") -> "_458.FaceGearMeshRating":
        from mastapy._private.gears.rating.face import _458

        return self.__parent__._cast(_458.FaceGearMeshRating)

    @property
    def cylindrical_gear_mesh_rating(
        self: "CastSelf",
    ) -> "_469.CylindricalGearMeshRating":
        from mastapy._private.gears.rating.cylindrical import _469

        return self.__parent__._cast(_469.CylindricalGearMeshRating)

    @property
    def conical_gear_mesh_rating(self: "CastSelf") -> "_550.ConicalGearMeshRating":
        from mastapy._private.gears.rating.conical import _550

        return self.__parent__._cast(_550.ConicalGearMeshRating)

    @property
    def concept_gear_mesh_rating(self: "CastSelf") -> "_561.ConceptGearMeshRating":
        from mastapy._private.gears.rating.concept import _561

        return self.__parent__._cast(_561.ConceptGearMeshRating)

    @property
    def bevel_gear_mesh_rating(self: "CastSelf") -> "_565.BevelGearMeshRating":
        from mastapy._private.gears.rating.bevel import _565

        return self.__parent__._cast(_565.BevelGearMeshRating)

    @property
    def agma_gleason_conical_gear_mesh_rating(
        self: "CastSelf",
    ) -> "_576.AGMAGleasonConicalGearMeshRating":
        from mastapy._private.gears.rating.agma_gleason_conical import _576

        return self.__parent__._cast(_576.AGMAGleasonConicalGearMeshRating)

    @property
    def gear_mesh_rating(self: "CastSelf") -> "GearMeshRating":
        return self.__parent__

    def __getattr__(self: "CastSelf", name: str) -> "Any":
        try:
            return self.__getattribute__(name)
        except AttributeError:
            class_name = utility.camel(name)
            raise CastException(
                f'Detected an invalid cast. Cannot cast to type "{class_name}"'
            ) from None


@extended_dataclass(frozen=True, slots=True, weakref_slot=True)
class GearMeshRating(_363.AbstractGearMeshRating):
    """GearMeshRating

    This is a mastapy class.
    """

    TYPE: ClassVar["Type"] = _GEAR_MESH_RATING

    wrapped: "Any"

    def __post_init__(self: "Self") -> None:
        """Override of the post initialisation magic method."""
        if not hasattr(self.wrapped, "reference_count"):
            self.wrapped.reference_count = 0

        self.wrapped.reference_count += 1

    @property
    def calculated_energy_loss(self: "Self") -> "float":
        """float

        Note:
            This property is readonly.
        """
        temp = self.wrapped.CalculatedEnergyLoss

        if temp is None:
            return 0.0

        return temp

    @property
    def calculated_mesh_efficiency(self: "Self") -> "float":
        """float

        Note:
            This property is readonly.
        """
        temp = self.wrapped.CalculatedMeshEfficiency

        if temp is None:
            return 0.0

        return temp

    @property
    def driving_gear(self: "Self") -> "str":
        """str

        Note:
            This property is readonly.
        """
        temp = self.wrapped.DrivingGear

        if temp is None:
            return ""

        return temp

    @property
    def is_loaded(self: "Self") -> "bool":
        """bool

        Note:
            This property is readonly.
        """
        temp = self.wrapped.IsLoaded

        if temp is None:
            return False

        return temp

    @property
    def pinion_name(self: "Self") -> "str":
        """str

        Note:
            This property is readonly.
        """
        temp = self.wrapped.PinionName

        if temp is None:
            return ""

        return temp

    @property
    def pinion_torque(self: "Self") -> "float":
        """float

        Note:
            This property is readonly.
        """
        temp = self.wrapped.PinionTorque

        if temp is None:
            return 0.0

        return temp

    @property
    def signed_pinion_torque(self: "Self") -> "float":
        """float

        Note:
            This property is readonly.
        """
        temp = self.wrapped.SignedPinionTorque

        if temp is None:
            return 0.0

        return temp

    @property
    def signed_wheel_torque(self: "Self") -> "float":
        """float

        Note:
            This property is readonly.
        """
        temp = self.wrapped.SignedWheelTorque

        if temp is None:
            return 0.0

        return temp

    @property
    def total_energy(self: "Self") -> "float":
        """float

        Note:
            This property is readonly.
        """
        temp = self.wrapped.TotalEnergy

        if temp is None:
            return 0.0

        return temp

    @property
    def wheel_name(self: "Self") -> "str":
        """str

        Note:
            This property is readonly.
        """
        temp = self.wrapped.WheelName

        if temp is None:
            return ""

        return temp

    @property
    def wheel_torque(self: "Self") -> "float":
        """float

        Note:
            This property is readonly.
        """
        temp = self.wrapped.WheelTorque

        if temp is None:
            return 0.0

        return temp

    @property
    def mesh_load_case(self: "Self") -> "_898.MeshLoadCase":
        """mastapy._private.gears.load_case.MeshLoadCase

        Note:
            This property is readonly.
        """
        temp = self.wrapped.MeshLoadCase

        if temp is None:
            return None

        type_ = temp.GetType()
        return constructor.new(type_.Namespace, type_.Name)(temp)

    @property
    def cast_to(self: "Self") -> "_Cast_GearMeshRating":
        """Cast to another type.

        Returns:
            _Cast_GearMeshRating
        """
        return _Cast_GearMeshRating(self)
